#!/usr/bin/env python
##
## @file    readSBML.py
## @brief   Similar to validateSBML, but without the validation
## @author  Sarah Keating
## @author  Ben Bornstein
##
## <!--------------------------------------------------------------------------
## This sample program is distributed under a different license than the rest
## of libSBML.  This program uses the open-source MIT license, as follows:
##
## Copyright (c) 2013-2018 by the California Institute of Technology
## (California, USA), the European Bioinformatics Institute (EMBL-EBI, UK)
## and the University of Heidelberg (Germany), with support from the National
## Institutes of Health (USA) under grant R01GM070923.  All rights reserved.
##
## Permission is hereby granted, free of charge, to any person obtaining a
## copy of this software and associated documentation files (the "Software"),
## to deal in the Software without restriction, including without limitation
## the rights to use, copy, modify, merge, publish, distribute, sublicense,
## and/or sell copies of the Software, and to permit persons to whom the
## Software is furnished to do so, subject to the following conditions:
##
## The above copyright notice and this permission notice shall be included in
## all copies or substantial portions of the Software.
##
## THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
## IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
## FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
## THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
## LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
## FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
## DEALINGS IN THE SOFTWARE.
##
## Neither the name of the California Institute of Technology (Caltech), nor
## of the European Bioinformatics Institute (EMBL-EBI), nor of the University
## of Heidelberg, nor the names of any contributors, may be used to endorse
## or promote products derived from this software without specific prior
## written permission.
## ------------------------------------------------------------------------ -->

import sys
import time
import os
import os.path
from libsbml import *

def main (args):
  """Usage: readSBML filename
  """

  if len(args) != 2:
      print("Usage: readSBML filename")
      return 1

  filename = args[1]
  current = time.time()
  document = readSBML(filename)

  errors = document.getNumErrors()

  print()
  print("            filename: " + filename)
  print("           file size: " + str(os.stat(filename).st_size))
  print("      read time (ms): " + str((time.time() - current)*1000))
  print(" validation error(s): " + str(errors))
  print()
  document.printErrors()

  return errors


if __name__ == '__main__':
  main(sys.argv)



#
# @file    TestReadFromFile6.py
# @brief   Reads test-data/l2v2-newComponents.xml into memory and tests it.
#
# @author  Akiya Jouraku (Python conversion)
# @author  Sarah Keating 
# 
# ====== WARNING ===== WARNING ===== WARNING ===== WARNING ===== WARNING ======
#
# DO NOT EDIT THIS FILE.
#
# This file was generated automatically by converting the file located at
# src/sbml/test/TestReadFromFile6.cpp
# using the conversion program dev/utilities/translateTests/translateTests.pl.
# Any changes made here will be lost the next time the file is regenerated.
#
# -----------------------------------------------------------------------------
# This file is part of libSBML.  Please visit http://sbml.org for more
# information about SBML, and the latest version of libSBML.
#
# Copyright 2005-2010 California Institute of Technology.
# Copyright 2002-2005 California Institute of Technology and
#                     Japan Science and Technology Corporation.
# 
# This library is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation.  A copy of the license agreement is provided
# in the file named "LICENSE.txt" included with this software distribution
# and also available online as http://sbml.org/software/libsbml/license.html
# -----------------------------------------------------------------------------

import sys
import unittest
import libsbml


class TestReadFromFile6(unittest.TestCase):


  def test_read_l2v2_newComponents(self):
    reader = libsbml.SBMLReader()
    filename = "../../sbml/test/test-data/"
    filename += "l2v2-newComponents.xml"
    d = reader.readSBML(filename)
    if (d == None):
      pass    
    self.assertTrue( d.getLevel() == 2 )
    self.assertTrue( d.getVersion() == 2 )
    m = d.getModel()
    self.assertTrue( m != None )
    self.assertTrue( m.getId() ==  "l2v2_newComponents" )
    self.assertTrue( m.getSBOTerm() == 4 )
    self.assertTrue( m.getSBOTermID() ==  "SBO:0000004" )
    self.assertTrue( m.getNumCompartments() == 2 )
    c = m.getCompartment(0)
    self.assertTrue( c != None )
    self.assertTrue( c.getId() ==  "cell" )
    self.assertTrue( c.getCompartmentType() ==  "mitochondria" )
    self.assertTrue( c.getOutside() ==  "m" )
    self.assertTrue( c.getSBOTerm() == -1 )
    self.assertTrue( c.getSBOTermID() ==  "" )
    c = m.getCompartment(1)
    self.assertTrue( c != None )
    self.assertTrue( c.getId() ==  "m" )
    self.assertTrue( c.getCompartmentType() ==  "mitochondria" )
    self.assertTrue( m.getNumCompartmentTypes() == 1 )
    ct = m.getCompartmentType(0)
    self.assertTrue( ct != None )
    self.assertTrue( ct.getId() ==  "mitochondria" )
    loct = m.getListOfCompartmentTypes()
    ct1 = loct.get(0)
    self.assertTrue( ct1 == ct )
    ct1 = loct.get("mitochondria")
    self.assertTrue( ct1 == ct )
    self.assertTrue( m.getNumSpeciesTypes() == 1 )
    st = m.getSpeciesType(0)
    self.assertTrue( st != None )
    self.assertTrue( st.getId() ==  "Glucose" )
    self.assertTrue( m.getNumSpecies() == 2 )
    s = m.getSpecies(0)
    self.assertTrue( s != None )
    self.assertTrue( s.getId() ==  "X0" )
    self.assertTrue( s.getSpeciesType() ==  "Glucose" )
    self.assertTrue( s.getCompartment() ==  "cell" )
    self.assertEqual( False, s.isSetInitialAmount() )
    self.assertEqual( False, s.isSetInitialConcentration() )
    s = m.getSpecies(1)
    self.assertTrue( s != None )
    self.assertTrue( s.getId() ==  "X1" )
    self.assertEqual( False, s.isSetSpeciesType() )
    self.assertTrue( s.getCompartment() ==  "cell" )
    self.assertTrue( s.getInitialConcentration() == 0.013 )
    self.assertEqual( False, s.isSetInitialAmount() )
    self.assertEqual( True, s.isSetInitialConcentration() )
    self.assertTrue( m.getNumParameters() == 1 )
    p = m.getParameter(0)
    self.assertTrue( p != None )
    self.assertTrue( p.getId() ==  "y" )
    self.assertTrue( p.getValue() == 2 )
    self.assertTrue( p.getUnits() ==  "dimensionless" )
    self.assertTrue( p.getId() ==  "y" )
    self.assertTrue( p.getSBOTerm() == 2 )
    self.assertTrue( p.getSBOTermID() ==  "SBO:0000002" )
    self.assertTrue( m.getNumConstraints() == 1 )
    con = m.getConstraint(0)
    self.assertTrue( con != None )
    self.assertTrue( con.getSBOTerm() == 64 )
    self.assertTrue( con.getSBOTermID() ==  "SBO:0000064" )
    ast = con.getMath()
    self.assertTrue((  "lt(1, cell)" == libsbml.formulaToString(ast) ))
    locon = m.getListOfConstraints()
    con1 = locon.get(0)
    self.assertTrue( con1 == con )
    self.assertTrue( m.getNumInitialAssignments() == 1 )
    ia = m.getInitialAssignment(0)
    self.assertTrue( ia != None )
    self.assertTrue( ia.getSBOTerm() == 64 )
    self.assertTrue( ia.getSBOTermID() ==  "SBO:0000064" )
    self.assertTrue( ia.getSymbol() ==  "X0" )
    ast = ia.getMath()
    self.assertTrue((  "y * X1" == libsbml.formulaToString(ast) ))
    loia = m.getListOfInitialAssignments()
    ia1 = loia.get(0)
    self.assertTrue( ia1 == ia )
    ia1 = loia.get("X0")
    self.assertTrue( ia1 == ia )
    self.assertTrue( m.getNumReactions() == 1 )
    r = m.getReaction(0)
    self.assertTrue( r != None )
    self.assertTrue( r.getSBOTerm() == 231 )
    self.assertTrue( r.getSBOTermID() ==  "SBO:0000231" )
    self.assertTrue( r.getId() ==  "in" )
    lor = m.getListOfReactions()
    r1 = lor.get(0)
    self.assertTrue( r1 == r )
    r1 = lor.get("in")
    self.assertTrue( r1 == r )
    self.assertEqual( True, r.isSetKineticLaw() )
    kl = r.getKineticLaw()
    self.assertTrue( kl != None )
    self.assertTrue( kl.getSBOTerm() == 1 )
    self.assertTrue( kl.getSBOTermID() ==  "SBO:0000001" )
    self.assertEqual( True, kl.isSetMath() )
    ast = kl.getMath()
    self.assertTrue((  "v * X0 / t" == libsbml.formulaToString(ast) ))
    self.assertTrue( kl.getNumParameters() == 2 )
    p = kl.getParameter(0)
    self.assertTrue( p != None )
    self.assertTrue( p.getSBOTerm() == 2 )
    self.assertTrue( p.getSBOTermID() ==  "SBO:0000002" )
    self.assertTrue( p.getId() ==  "v" )
    self.assertTrue( p.getUnits() ==  "litre" )
    self.assertTrue( r.getNumReactants() == 1 )
    self.assertTrue( r.getNumProducts() == 0 )
    self.assertTrue( r.getNumModifiers() == 0 )
    sr = r.getReactant(0)
    self.assertTrue( sr != None )
    self.assertTrue( sr.getName() ==  "sarah" )
    self.assertTrue( sr.getId() ==  "me" )
    self.assertTrue( sr.getSpecies() ==  "X0" )
    losr = r.getListOfReactants()
    sr1 = losr.get(0)
    self.assertTrue( sr1 == sr )
    sr1 = losr.get("me")
    self.assertTrue( sr1 == sr )
    d = None
    pass  

def suite():
  suite = unittest.TestSuite()
  suite.addTest(unittest.makeSuite(TestReadFromFile6))

  return suite

if __name__ == "__main__":
  if unittest.TextTestRunner(verbosity=1).run(suite()).wasSuccessful() :
    sys.exit(0)
  else:
    sys.exit(1)



#
# @file    TestCompartmentType_newSetters.py
# @brief   CompartmentType unit tests for new set function API
#
# @author  Akiya Jouraku (Python conversion)
# @author  Sarah Keating 
# 
# ====== WARNING ===== WARNING ===== WARNING ===== WARNING ===== WARNING ======
#
# DO NOT EDIT THIS FILE.
#
# This file was generated automatically by converting the file located at
# src/sbml/test/TestCompartmentType_newSetters.c
# using the conversion program dev/utilities/translateTests/translateTests.pl.
# Any changes made here will be lost the next time the file is regenerated.
#
# -----------------------------------------------------------------------------
# This file is part of libSBML.  Please visit http://sbml.org for more
# information about SBML, and the latest version of libSBML.
#
# Copyright 2005-2010 California Institute of Technology.
# Copyright 2002-2005 California Institute of Technology and
#                     Japan Science and Technology Corporation.
# 
# This library is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation.  A copy of the license agreement is provided
# in the file named "LICENSE.txt" included with this software distribution
# and also available online as http://sbml.org/software/libsbml/license.html
# -----------------------------------------------------------------------------

import sys
import unittest
import libsbml


class TestCompartmentType_newSetters(unittest.TestCase):

  global C
  C = None

  def setUp(self):
    self.C = libsbml.CompartmentType(2,2)
    if (self.C == None):
      pass    
    pass  

  def tearDown(self):
    _dummyList = [ self.C ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_CompartmentType_setId2(self):
    i = self.C.setId( "1cell")
    self.assertTrue( i == libsbml.LIBSBML_INVALID_ATTRIBUTE_VALUE )
    self.assertEqual( False, self.C.isSetId() )
    pass  

  def test_CompartmentType_setId3(self):
    i = self.C.setId( "cell")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( True, self.C.isSetId() )
    self.assertTrue((  "cell"  == self.C.getId() ))
    pass  

  def test_CompartmentType_setId4(self):
    i = self.C.setId("")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( False, self.C.isSetId() )
    pass  

  def test_CompartmentType_setName1(self):
    i = self.C.setName( "cell")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( True, self.C.isSetName() )
    i = self.C.unsetName()
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( False, self.C.isSetName() )
    pass  

  def test_CompartmentType_setName2(self):
    i = self.C.setName( "1cell")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( True, self.C.isSetName() )
    i = self.C.unsetName()
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( False, self.C.isSetName() )
    pass  

  def test_CompartmentType_setName3(self):
    i = self.C.setName("")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( False, self.C.isSetName() )
    pass  

def suite():
  suite = unittest.TestSuite()
  suite.addTest(unittest.makeSuite(TestCompartmentType_newSetters))

  return suite

if __name__ == "__main__":
  if unittest.TextTestRunner(verbosity=1).run(suite()).wasSuccessful() :
    sys.exit(0)
  else:
    sys.exit(1)



#!/usr/bin/env python

import unittest
import rewrite_pydoc
import tempfile

class TestWrite(unittest.TestCase):

    def test_file_write_action(self):
        tmpfile = tempfile.mkstemp()[1]
        rewrite_pydoc.write_output_file(tmpfile, 'The contents.\n')

    def test_file_write_contents(self):
        tmpfile = tempfile.mkstemp()[1]
        rewrite_pydoc.write_output_file(tmpfile, 'The contents.\n')
        istream = open(tmpfile, 'r')
        contents = istream.read()
        self.assertEqual(contents, 'The contents.\n')

def main():
    unittest.main()

if __name__ == '__main__':
    main()



#!/usr/bin/env python
##
## @file    flattenArrays.py
## @brief   Flattens the arrays code from the given SBML file.
## @author  Brett G. Olivier
##
##
## <!--------------------------------------------------------------------------
## This sample program is distributed under a different license than the rest
## of libSBML.  This program uses the open-source MIT license, as follows:
##
## Copyright (c) 2013-2018 by the California Institute of Technology
## (California, USA), the European Bioinformatics Institute (EMBL-EBI, UK)
## and the University of Heidelberg (Germany), with support from the National
## Institutes of Health (USA) under grant R01GM070923.  All rights reserved.
##
## Permission is hereby granted, free of charge, to any person obtaining a
## copy of this software and associated documentation files (the "Software"),
## to deal in the Software without restriction, including without limitation
## the rights to use, copy, modify, merge, publish, distribute, sublicense,
## and/or sell copies of the Software, and to permit persons to whom the
## Software is furnished to do so, subject to the following conditions:
##
## The above copyright notice and this permission notice shall be included in
## all copies or substantial portions of the Software.
##
## THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
## IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
## FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
## THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
## LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
## FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
## DEALINGS IN THE SOFTWARE.
##
## Neither the name of the California Institute of Technology (Caltech), nor
## of the European Bioinformatics Institute (EMBL-EBI), nor of the University
## of Heidelberg, nor the names of any contributors, may be used to endorse
## or promote products derived from this software without specific prior
## written permission.
## ------------------------------------------------------------------------ -->

import sys
import os.path
import libsbml

def main (args):
    """usage: flattenArrays.py input-filename output-filename
    """
    if len(args) != 3:
        print(main.__doc__)
        sys.exit(1)

    infile  = args[1]
    outfile = args[2]

    if not os.path.exists(infile):
        print("[Error] {} : No such file.".format(infile))
        sys.exit(1)

    reader  = libsbml.SBMLReader()
    writer  = libsbml.SBMLWriter()
    sbmldoc = reader.readSBML(infile)

    if sbmldoc.getNumErrors() > 0:
        if sbmldoc.getError(0).getErrorId() == libsbml.XMLFileUnreadable:
            # Handle case of unreadable file here.
            sbmldoc.printErrors()
        elif sbmldoc.getError(0).getErrorId() == libsbml.XMLFileOperationError:
            # Handle case of other file error here.
            sbmldoc.printErrors()
        else:
            # Handle other error cases here.
            sbmldoc.printErrors()
        
        sys.exit(1)

    props = libsbml.ConversionProperties()
    props.addOption("flatten arrays", True, "flatten arrays")
    # Optional: validate flattened file ... may take some time
    # props.addOption("performValidation", True, "perform validation before and after trying to flatten")

    result = sbmldoc.convert(props)
    if (result != libsbml.LIBSBML_OPERATION_SUCCESS):
        print("[Error] Array flattening failed... ({})".format(result))
        sys.exit(1)

    writer.writeSBML(sbmldoc, outfile)
    print("[OK] Flattened arrays file {} to {}".format(infile, outfile))

if __name__ == '__main__':
    main(sys.argv)



#!/usr/bin/env python

import unittest

class TestTest(unittest.TestCase):

    def test_true(self):
        self.failUnless(True)

def main():
    unittest.main()

if __name__ == '__main__':
    main()



#!/usr/bin/env python

from xml.dom.minidom import *
import sys, os


def get_value(node, name):
    temp = node.getAttributeNode(name)
    if temp is None:
        return None
    return temp.nodeValue


def get_adjusted_name(node):
    name = get_value(node, 'name')
    if name == 'Bourne Shell':
        adjusted_name = '.sh/.bat'
    elif name == 'HTML':
        adjusted_name = 'Doc scripts'
    elif name == 'make':
        adjusted_name = 'GNU make'
    elif name == 'SWIG interface':
        adjusted_name = 'SWIG definitions'
    elif name == 'm4':
        adjusted_name = 'M4'
    else:
        adjusted_name = name
    return adjusted_name


def parse_cloc_xml(filename):

    dom = parse(filename)

    all_languages = []

    for node in dom.getElementsByTagName('language'):
        name = get_adjusted_name(node)
        no_files = get_value(node, 'files_count')
        comment = get_value(node, 'comment')
        code = get_value(node, 'code')

        language = dict({'name': name,
                         'files': no_files,
                         'comment': comment,
                         'code': code})

        all_languages.append(language)

    for node in dom.getElementsByTagName('total'):
        no_files = get_value(node, 'sum_files')
        comment = get_value(node, 'comment')
        code = get_value(node, 'code')

        total = dict({'num_files': no_files,
                      'comment': comment,
                      'code': code})

    data = dict({'languages': all_languages,
                 'totals': total})
    return data


def get_index(languages, language):
    index = 0
    while (index < len(languages) and languages[index]['name'] != language):
        index += 1
    if index >= len(languages):
        return -1
    else:
        return index



def get_line(languages, language):
    i = get_index(languages, language)
    if i == -1:
        return 'ERROR ENCOUNTERED'
    else:
        numbers = languages[i]
        if language == '.sh/.bat':
            language = '\\texttt{.sh}/\\texttt{.bat}'
        return '{:16s} & {:10s} & {:6s} & {:6s}'.format(language, numbers['files'], numbers['code'], numbers['comment'])




def main(args):
    if not os.path.isfile('results_cloc.xml'):
        print ('The cloc program needs to be run before the output can be processed.'
               ' Please run count.bat/count.sh to create the appropriate file.')
        return
    data = parse_cloc_xml('results_cloc.xml')

    file_out = open('loc_table.tex', 'w')

    file_out.write('  \\begin{tabular}[t]{lrrrr}\n')
    file_out.write('    \\toprule\n')
    file_out.write('                       &                   & \\textbf{Code}  & \\textls[-15]{\\textbf{Comment}}\\\\[-2pt]\n')
    file_out.write('    \\textbf{Language} & \\textbf{Files}   & \\textbf{Lines} & \\textbf{Lines}\\\\\n')
    file_out.write('    \\midrule\n')
    # okay not going to be clever and try and sort it
    # I know what order I want them in

    file_out.write('     {}\\\\\n'.format(get_line(data['languages'], 'C')))
    file_out.write('     {}\\\\\n'.format(get_line(data['languages'], 'C++')))
    file_out.write('     {}\\\\\n'.format(get_line(data['languages'], 'C/C++ Header')))
    file_out.write('     {}\\\\\n'.format(get_line(data['languages'], 'C\\#')))
    file_out.write('     {}\\\\\n'.format(get_line(data['languages'], 'CMake')))
    file_out.write('     {}\\\\\n'.format(get_line(data['languages'], 'GNU make')))
    file_out.write('     {}\\\\\n'.format(get_line(data['languages'], 'Java')))
    file_out.write('     {}\\\\\n'.format(get_line(data['languages'], 'Javascript')))
    file_out.write('     {}\\\\\n'.format(get_line(data['languages'], 'M4')))
    file_out.write('     {}\\\\\n'.format(get_line(data['languages'], 'MATLAB')))
    file_out.write('     {}\\\\\n'.format(get_line(data['languages'], 'Perl')))
    file_out.write('     {}\\\\\n'.format(get_line(data['languages'], 'PHP')))
    file_out.write('     {}\\\\\n'.format(get_line(data['languages'], 'Python')))
    file_out.write('     {}\\\\\n'.format(get_line(data['languages'], 'R')))
    file_out.write('     {}\\\\\n'.format(get_line(data['languages'], 'Ruby')))
    file_out.write('     {}\\\\\n'.format(get_line(data['languages'], '.sh/.bat')))
    file_out.write('     {}\\\\\n'.format(get_line(data['languages'], 'SWIG definitions')))
    file_out.write('     {}\\\\\n'.format(get_line(data['languages'], 'XML')))
    file_out.write('    \\midrule\n')
    file_out.write('    \\emph{:16s}  & {:10s} & {:10s} & {:10s} \\\\\n'.format('{Total}', data['totals']['num_files'], data['totals']['code'], data['totals']['comment']))
    file_out.write('    \\bottomrule\n')
    file_out.write('  \\end{tabular}\n')

    file_out.close()

    print('loc_table.tex has been successfully written')

if __name__ == '__main__':
    main(sys.argv)


#
# @file    TestL3ModelHistory.py
# @brief   test for ModelHistory on any SBase object
#
# @author  Akiya Jouraku (Python conversion)
# @author  Sarah Keating 
# 
# ====== WARNING ===== WARNING ===== WARNING ===== WARNING ===== WARNING ======
#
# DO NOT EDIT THIS FILE.
#
# This file was generated automatically by converting the file located at
# src/sbml/test/TestL3ModelHistory.cpp
# using the conversion program dev/utilities/translateTests/translateTests.pl.
# Any changes made here will be lost the next time the file is regenerated.
#
# -----------------------------------------------------------------------------
# This file is part of libSBML.  Please visit http://sbml.org for more
# information about SBML, and the latest version of libSBML.
#
# Copyright 2005-2010 California Institute of Technology.
# Copyright 2002-2005 California Institute of Technology and
#                     Japan Science and Technology Corporation.
# 
# This library is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation.  A copy of the license agreement is provided
# in the file named "LICENSE.txt" included with this software distribution
# and also available online as http://sbml.org/software/libsbml/license.html
# -----------------------------------------------------------------------------

import sys
import unittest
import libsbml

def wrapString(s):
  return s
  pass


class TestL3ModelHistory(unittest.TestCase):

  global c
  c = None
  global d
  d = None
  global m
  m = None

  def equals(self, *x):
    if len(x) == 2:
      return x[0] == x[1]
    elif len(x) == 1:
      return x[0] == self.OSS.str()

  def setUp(self):
    filename = "../../sbml/annotation/test/test-data/annotationL3.xml"
    self.d = libsbml.readSBML(filename)
    self.m = self.d.getModel()
    self.c = self.m.getCompartment(0)
    pass  

  def tearDown(self):
    self.d = None
    pass  

  def test_L3ModelHistory_delete(self):
    node = libsbml.RDFAnnotationParser.parseModelHistory(self.c)
    n1 = libsbml.RDFAnnotationParser.deleteRDFAnnotation(node)
    expected =  "<annotation/>";
    self.assertTrue( n1.getNumChildren() == 0 )
    self.assertTrue( n1.getName() ==  "annotation" )
    self.assertEqual( True, self.equals(expected,n1.toXMLString()) )
    node = None
    pass  

  def test_L3ModelHistory_deleteWithOther(self):
    self.c = self.m.getCompartment(1)
    node = libsbml.RDFAnnotationParser.deleteRDFAnnotation(self.c.getAnnotation())
    expected = wrapString("<annotation>\n" + "  <jd2:JDesignerLayout version=\"2.0\" MajorVersion=\"2\" MinorVersion=\"0\" BuildVersion=\"41\">\n" + 
    "    <jd2:header>\n" + 
    "      <jd2:VersionHeader JDesignerVersion=\"2.0\"/>\n" + 
    "      <jd2:ModelHeader Author=\"Mr Untitled\" ModelVersion=\"0.0\" ModelTitle=\"untitled\"/>\n" + 
    "      <jd2:TimeCourseDetails timeStart=\"0\" timeEnd=\"10\" numberOfPoints=\"1000\"/>\n" + 
    "    </jd2:header>\n" + 
    "  </jd2:JDesignerLayout>\n" + 
    "</annotation>")
    self.assertEqual( True, self.equals(expected,node.toXMLString()) )
    pass  

  def test_L3ModelHistory_deleteWithOutOther(self):
    self.c = self.m.getCompartment(2)
    node = self.c.getAnnotation()
    expected = wrapString("<annotation>\n" + "  <jd2:JDesignerLayout version=\"2.0\" MajorVersion=\"2\" MinorVersion=\"0\" BuildVersion=\"41\">\n" + 
    "    <jd2:header>\n" + 
    "      <jd2:VersionHeader JDesignerVersion=\"2.0\"/>\n" + 
    "      <jd2:ModelHeader Author=\"Mr Untitled\" ModelVersion=\"0.0\" ModelTitle=\"untitled\"/>\n" + 
    "      <jd2:TimeCourseDetails timeStart=\"0\" timeEnd=\"10\" numberOfPoints=\"1000\"/>\n" + 
    "    </jd2:header>\n" + 
    "  </jd2:JDesignerLayout>\n" + 
    "</annotation>")
    self.assertEqual( True, self.equals(expected,node.toXMLString()) )
    pass  

  def test_L3ModelHistory_delete_Model(self):
    node = libsbml.RDFAnnotationParser.parseModelHistory(self.m)
    n1 = libsbml.RDFAnnotationParser.deleteRDFAnnotation(node)
    expected =  "<annotation/>";
    self.assertTrue( n1.getNumChildren() == 0 )
    self.assertTrue( n1.getName() ==  "annotation" )
    self.assertEqual( True, self.equals(expected,n1.toXMLString()) )
    node = None
    pass  

  def test_L3ModelHistory_getModelHistory(self):
    self.assertTrue( (self.c == None) == False )
    history = self.c.getModelHistory()
    self.assertTrue( history != None )
    mc = history.getCreator(0)
    self.assertTrue((  "Le Novere" == mc.getFamilyName() ))
    self.assertTrue((  "Nicolas" == mc.getGivenName() ))
    self.assertTrue((  "lenov@ebi.ac.uk" == mc.getEmail() ))
    self.assertTrue((  "EMBL-EBI" == mc.getOrganisation() ))
    date = history.getCreatedDate()
    self.assertTrue( date.getYear() == 2005 )
    self.assertTrue( date.getMonth() == 2 )
    self.assertTrue( date.getDay() == 2 )
    self.assertTrue( date.getHour() == 14 )
    self.assertTrue( date.getMinute() == 56 )
    self.assertTrue( date.getSecond() == 11 )
    self.assertTrue( date.getSignOffset() == 0 )
    self.assertTrue( date.getHoursOffset() == 0 )
    self.assertTrue( date.getMinutesOffset() == 0 )
    self.assertTrue((  "2005-02-02T14:56:11Z" == date.getDateAsString() ))
    date = history.getModifiedDate()
    self.assertTrue( date.getYear() == 2006 )
    self.assertTrue( date.getMonth() == 5 )
    self.assertTrue( date.getDay() == 30 )
    self.assertTrue( date.getHour() == 10 )
    self.assertTrue( date.getMinute() == 46 )
    self.assertTrue( date.getSecond() == 2 )
    self.assertTrue( date.getSignOffset() == 0 )
    self.assertTrue( date.getHoursOffset() == 0 )
    self.assertTrue( date.getMinutesOffset() == 0 )
    self.assertTrue((  "2006-05-30T10:46:02Z" == date.getDateAsString() ))
    pass  

  def test_L3ModelHistory_getModelHistory_Model(self):
    self.assertTrue( (self.m == None) == False )
    history = self.m.getModelHistory()
    self.assertTrue( history != None )
    mc = history.getCreator(0)
    self.assertTrue((  "Le Novere" == mc.getFamilyName() ))
    self.assertTrue((  "Nicolas" == mc.getGivenName() ))
    self.assertTrue((  "lenov@ebi.ac.uk" == mc.getEmail() ))
    self.assertTrue((  "EMBL-EBI" == mc.getOrganisation() ))
    date = history.getCreatedDate()
    self.assertTrue( date.getYear() == 2005 )
    self.assertTrue( date.getMonth() == 2 )
    self.assertTrue( date.getDay() == 2 )
    self.assertTrue( date.getHour() == 14 )
    self.assertTrue( date.getMinute() == 56 )
    self.assertTrue( date.getSecond() == 11 )
    self.assertTrue( date.getSignOffset() == 0 )
    self.assertTrue( date.getHoursOffset() == 0 )
    self.assertTrue( date.getMinutesOffset() == 0 )
    self.assertTrue((  "2005-02-02T14:56:11Z" == date.getDateAsString() ))
    date = history.getModifiedDate()
    self.assertTrue( date.getYear() == 2006 )
    self.assertTrue( date.getMonth() == 5 )
    self.assertTrue( date.getDay() == 30 )
    self.assertTrue( date.getHour() == 10 )
    self.assertTrue( date.getMinute() == 46 )
    self.assertTrue( date.getSecond() == 2 )
    self.assertTrue( date.getSignOffset() == 0 )
    self.assertTrue( date.getHoursOffset() == 0 )
    self.assertTrue( date.getMinutesOffset() == 0 )
    self.assertTrue((  "2006-05-30T10:46:02Z" == date.getDateAsString() ))
    pass  

  def test_L3ModelHistory_parseModelHistory(self):
    node = libsbml.RDFAnnotationParser.parseModelHistory(self.c)
    self.assertTrue( node.getNumChildren() == 1 )
    rdf = node.getChild(0)
    self.assertTrue((  "RDF" == rdf.getName() ))
    self.assertTrue((  "rdf" == rdf.getPrefix() ))
    self.assertTrue((  "http://www.w3.org/1999/02/22-rdf-syntax-ns#" == rdf.getURI() ))
    self.assertTrue( rdf.getNumChildren() == 1 )
    desc = rdf.getChild(0)
    self.assertTrue((  "Description" == desc.getName() ))
    self.assertTrue((  "rdf" == desc.getPrefix() ))
    self.assertTrue((  "http://www.w3.org/1999/02/22-rdf-syntax-ns#" == desc.getURI() ))
    self.assertTrue( desc.getNumChildren() == 4 )
    creator = desc.getChild(0)
    self.assertTrue((  "creator" == creator.getName() ))
    self.assertTrue((  "dcterms" == creator.getPrefix() ))
    self.assertTrue( creator.getNumChildren() == 1 )
    Bag = creator.getChild(0)
    self.assertTrue((  "Bag" == Bag.getName() ))
    self.assertTrue((  "rdf" == Bag.getPrefix() ))
    self.assertTrue((  "http://www.w3.org/1999/02/22-rdf-syntax-ns#" == Bag.getURI() ))
    self.assertTrue( Bag.getNumChildren() == 1 )
    li = Bag.getChild(0)
    self.assertTrue((  "li" == li.getName() ))
    self.assertTrue((  "rdf" == li.getPrefix() ))
    self.assertTrue((  "http://www.w3.org/1999/02/22-rdf-syntax-ns#" == li.getURI() ))
    self.assertTrue( li.getNumChildren() == 3 )
    N = li.getChild(0)
    self.assertTrue((  "N" == N.getName() ))
    self.assertTrue((  "vCard" == N.getPrefix() ))
    self.assertTrue((  "http://www.w3.org/2001/vcard-rdf/3.0#" == N.getURI() ))
    self.assertTrue( N.getNumChildren() == 2 )
    Family = N.getChild(0)
    self.assertTrue((  "Family" == Family.getName() ))
    self.assertTrue((  "vCard" == Family.getPrefix() ))
    self.assertTrue((  "http://www.w3.org/2001/vcard-rdf/3.0#" == Family.getURI() ))
    self.assertTrue( Family.getNumChildren() == 1 )
    Given = N.getChild(1)
    self.assertTrue((  "Given" == Given.getName() ))
    self.assertTrue((  "vCard" == Given.getPrefix() ))
    self.assertTrue((  "http://www.w3.org/2001/vcard-rdf/3.0#" == Given.getURI() ))
    self.assertTrue( Given.getNumChildren() == 1 )
    EMAIL = li.getChild(1)
    self.assertTrue((  "EMAIL" == EMAIL.getName() ))
    self.assertTrue((  "vCard" == EMAIL.getPrefix() ))
    self.assertTrue((  "http://www.w3.org/2001/vcard-rdf/3.0#" == EMAIL.getURI() ))
    self.assertTrue( EMAIL.getNumChildren() == 1 )
    ORG = li.getChild(2)
    self.assertTrue((  "ORG" == ORG.getName() ))
    self.assertTrue((  "vCard" == ORG.getPrefix() ))
    self.assertTrue((  "http://www.w3.org/2001/vcard-rdf/3.0#" == ORG.getURI() ))
    self.assertTrue( ORG.getNumChildren() == 1 )
    Orgname = ORG.getChild(0)
    self.assertTrue((  "Orgname" == Orgname.getName() ))
    self.assertTrue((  "vCard" == Orgname.getPrefix() ))
    self.assertTrue((  "http://www.w3.org/2001/vcard-rdf/3.0#" == Orgname.getURI() ))
    self.assertTrue( Orgname.getNumChildren() == 1 )
    created = desc.getChild(1)
    self.assertTrue((  "created" == created.getName() ))
    self.assertTrue((  "dcterms" == created.getPrefix() ))
    self.assertTrue((  "http://purl.org/dc/terms/" == created.getURI() ))
    self.assertTrue( created.getNumChildren() == 1 )
    cr_date = created.getChild(0)
    self.assertTrue((  "W3CDTF" == cr_date.getName() ))
    self.assertTrue((  "dcterms" == cr_date.getPrefix() ))
    self.assertTrue((  "http://purl.org/dc/terms/" == cr_date.getURI() ))
    self.assertTrue( cr_date.getNumChildren() == 1 )
    modified = desc.getChild(2)
    self.assertTrue((  "modified" == modified.getName() ))
    self.assertTrue((  "dcterms" == modified.getPrefix() ))
    self.assertTrue((  "http://purl.org/dc/terms/" == modified.getURI() ))
    self.assertTrue( modified.getNumChildren() == 1 )
    mo_date = created.getChild(0)
    self.assertTrue((  "W3CDTF" == mo_date.getName() ))
    self.assertTrue((  "dcterms" == mo_date.getPrefix() ))
    self.assertTrue((  "http://purl.org/dc/terms/" == mo_date.getURI() ))
    self.assertTrue( mo_date.getNumChildren() == 1 )
    node = None
    pass  

  def test_L3ModelHistory_parseModelHistory_Model(self):
    node = libsbml.RDFAnnotationParser.parseModelHistory(self.m)
    self.assertTrue( node.getNumChildren() == 1 )
    rdf = node.getChild(0)
    self.assertTrue((  "RDF" == rdf.getName() ))
    self.assertTrue((  "rdf" == rdf.getPrefix() ))
    self.assertTrue((  "http://www.w3.org/1999/02/22-rdf-syntax-ns#" == rdf.getURI() ))
    self.assertTrue( rdf.getNumChildren() == 1 )
    desc = rdf.getChild(0)
    self.assertTrue((  "Description" == desc.getName() ))
    self.assertTrue((  "rdf" == desc.getPrefix() ))
    self.assertTrue((  "http://www.w3.org/1999/02/22-rdf-syntax-ns#" == desc.getURI() ))
    self.assertTrue( desc.getNumChildren() == 4 )
    creator = desc.getChild(0)
    self.assertTrue((  "creator" == creator.getName() ))
    self.assertTrue((  "dcterms" == creator.getPrefix() ))
    self.assertTrue( creator.getNumChildren() == 1 )
    Bag = creator.getChild(0)
    self.assertTrue((  "Bag" == Bag.getName() ))
    self.assertTrue((  "rdf" == Bag.getPrefix() ))
    self.assertTrue((  "http://www.w3.org/1999/02/22-rdf-syntax-ns#" == Bag.getURI() ))
    self.assertTrue( Bag.getNumChildren() == 1 )
    li = Bag.getChild(0)
    self.assertTrue((  "li" == li.getName() ))
    self.assertTrue((  "rdf" == li.getPrefix() ))
    self.assertTrue((  "http://www.w3.org/1999/02/22-rdf-syntax-ns#" == li.getURI() ))
    self.assertTrue( li.getNumChildren() == 3 )
    N = li.getChild(0)
    self.assertTrue((  "N" == N.getName() ))
    self.assertTrue((  "vCard" == N.getPrefix() ))
    self.assertTrue((  "http://www.w3.org/2001/vcard-rdf/3.0#" == N.getURI() ))
    self.assertTrue( N.getNumChildren() == 2 )
    Family = N.getChild(0)
    self.assertTrue((  "Family" == Family.getName() ))
    self.assertTrue((  "vCard" == Family.getPrefix() ))
    self.assertTrue((  "http://www.w3.org/2001/vcard-rdf/3.0#" == Family.getURI() ))
    self.assertTrue( Family.getNumChildren() == 1 )
    Given = N.getChild(1)
    self.assertTrue((  "Given" == Given.getName() ))
    self.assertTrue((  "vCard" == Given.getPrefix() ))
    self.assertTrue((  "http://www.w3.org/2001/vcard-rdf/3.0#" == Given.getURI() ))
    self.assertTrue( Given.getNumChildren() == 1 )
    EMAIL = li.getChild(1)
    self.assertTrue((  "EMAIL" == EMAIL.getName() ))
    self.assertTrue((  "vCard" == EMAIL.getPrefix() ))
    self.assertTrue((  "http://www.w3.org/2001/vcard-rdf/3.0#" == EMAIL.getURI() ))
    self.assertTrue( EMAIL.getNumChildren() == 1 )
    ORG = li.getChild(2)
    self.assertTrue((  "ORG" == ORG.getName() ))
    self.assertTrue((  "vCard" == ORG.getPrefix() ))
    self.assertTrue((  "http://www.w3.org/2001/vcard-rdf/3.0#" == ORG.getURI() ))
    self.assertTrue( ORG.getNumChildren() == 1 )
    Orgname = ORG.getChild(0)
    self.assertTrue((  "Orgname" == Orgname.getName() ))
    self.assertTrue((  "vCard" == Orgname.getPrefix() ))
    self.assertTrue((  "http://www.w3.org/2001/vcard-rdf/3.0#" == Orgname.getURI() ))
    self.assertTrue( Orgname.getNumChildren() == 1 )
    created = desc.getChild(1)
    self.assertTrue((  "created" == created.getName() ))
    self.assertTrue((  "dcterms" == created.getPrefix() ))
    self.assertTrue((  "http://purl.org/dc/terms/" == created.getURI() ))
    self.assertTrue( created.getNumChildren() == 1 )
    cr_date = created.getChild(0)
    self.assertTrue((  "W3CDTF" == cr_date.getName() ))
    self.assertTrue((  "dcterms" == cr_date.getPrefix() ))
    self.assertTrue((  "http://purl.org/dc/terms/" == cr_date.getURI() ))
    self.assertTrue( cr_date.getNumChildren() == 1 )
    modified = desc.getChild(2)
    self.assertTrue((  "modified" == modified.getName() ))
    self.assertTrue((  "dcterms" == modified.getPrefix() ))
    self.assertTrue((  "http://purl.org/dc/terms/" == modified.getURI() ))
    self.assertTrue( modified.getNumChildren() == 1 )
    mo_date = created.getChild(0)
    self.assertTrue((  "W3CDTF" == mo_date.getName() ))
    self.assertTrue((  "dcterms" == mo_date.getPrefix() ))
    self.assertTrue((  "http://purl.org/dc/terms/" == mo_date.getURI() ))
    self.assertTrue( mo_date.getNumChildren() == 1 )
    node = None
    pass  


def suite():
  suite = unittest.TestSuite()
  suite.addTest(unittest.makeSuite(TestL3ModelHistory))

  return suite

if __name__ == "__main__":
  if unittest.TextTestRunner(verbosity=1).run(suite()).wasSuccessful() :
    sys.exit(0)
  else:
    sys.exit(1)



#!/usr/bin/env python
# =============================================================================
# @file   writeErrorTable.py
# @brief  Write documentation for SBML error codes
# @author Sarah Keating
# @author Michael Hucka
# =============================================================================
#
# This Python program interrogates the currently-installed libSBML library to
# generate documentation about the libSBML diagnostic codes, and generate
# output used in several contexts.  The output produced by this program is
# controlled by the first command-line argument given to it:
#
# * Given --doc, it will generate a table suitable for use in the libSBML
#   API documentation as it appears in the header of SBMLError.h.  The file
#   it produces is meant to replace src/sbml/common/common-sbmlerror-codes.h.
#   In other words, do the following:
#
#    writeErrorTable.py --doc ../../../src/sbml/common/common-sbmlerror-codes.h
#
# * Given --enum, it will generate the SBMLErrorCode_t enum for SBMLError.h.
#   (The output needs to be manually copied and pasted into SBMLError.h.)
#
# * Given --web, it will generate output used in the table in the web page at
#   http://sbml.org/Facilities/Documentation/Error_Categories.
#
# Here is a typical way of using this program:
#
# 1) Make any desired updates to the text of the diagnostic messages in
#    src/sbml/SBMLErrorTable.h.
#
# 2) Rebuild and install libSBML on your computer, with the Python bindings
#    enabled.  This is necessary because this program (writeErrorTable.py)
#    uses the libSBML Python bindings to do its work.
#
# 3) Configure your PYTHONPATH environment variable to encompass this newly-
#    installed copy of libSBML.  Double-check that your Python executable
#    is in fact picking up the copy of libSBML you think it is.
#
# 4) Run this program 3 times, as following
#
#      ./writeErrorTable.py --doc  doc-fragment.txt
#      ./writeErrorTable.py --enum enum.txt
#      ./writeErrorTable.py --web  sbmlerror-table.html
#
# 5) Replace sbmlerror-table.html on sbml.org, and edit SBMLError.h to
#    insert the contents of doc-fragment.txt and enum.txt in the appropriate
#    places.
#
#<!-- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
# This file is part of libSBML.  Please visit http://sbml.org for more
# information about SBML, and the latest version of libSBML.
#
# Copyright (C) 2013-2018 jointly by the following organizations:
#     1. California Institute of Technology, Pasadena, CA, USA
#     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
#     3. University of Heidelberg, Heidelberg, Germany
#
# Copyright (C) 2009-2013 jointly by the following organizations:
#     1. California Institute of Technology, Pasadena, CA, USA
#     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
#
# Copyright (C) 2006-2008 by the California Institute of Technology,
#     Pasadena, CA, USA
#
# Copyright (C) 2002-2005 jointly by the following organizations:
#     1. California Institute of Technology, Pasadena, CA, USA
#     2. Japan Science and Technology Agency, Japan
#
# This library is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation.  A copy of the license agreement is provided
# in the file named "LICENSE.txt" included with this software distribution
# and also available online as http://sbml.org/software/libsbml/license.html
# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

import re, os, sys

from types import *
from imp import *
from string import *
from libsbml import *


# -----------------------------------------------------------------------------
# Globals.
# -----------------------------------------------------------------------------

# The currently-known SBML Levels and Versions.

sbml_levels_versions = [[1, 1], [1, 2],
                        [2, 1], [2, 2], [2, 3], [2, 4],
                        [3, 1], [3, 2]]

# Set of error codes that we ignore for purposes of documentation.

ignored_error_codes = {9999, 10599, 20905, 21112, 29999, 90000, 90501, 99502,
                       99503, 99504, 99994, 99995, 99999}

# Package error code ranges.  The numbers are the low end start values.

package_codes = [['comp',   1000000],
                 ['fbc',    2000000],
                 ['qual',   3000000],
                 ['groups', 4000000],
                 ['layout', 6000000]]

# Our approach to finding error codes starts with numbers and then rummages
# through the list of symbols in the libSBML Python module to find the symbol
# that corresponds to each number.  That works well enough for our purposes
# when the number is above 100, but for lower numbers, we have collisions
# because there are many short enumerations in libSBML.  We don't care about
# numbers lower than 10000 when doing --enum or --doc, but we do for --web,
# where we try to list all error codes.  All of those enumerations turn into
# the same numbers starting from 0, so if you grab a symbol from the Python
# module and examine its value and find that it, say, "3", you can't tell
# which enumeration it came from.  You can only do that if you know the
# symbol names you care about ahead of time.  Since we don't want to
# hard-code all possible libSBML error codes here (avoiding that scenario is
# the point of this program!), we have to find some other way to distinguish
# the cases.  The approach taken here is to only worry about the numbers
# below 1000 using a table that enumerates the symbols we care about; when we
# iterate over all error numbers, we always explicitly map the numbers to the
# following codes.

low_numbered_errors = { 0   : 'XMLUnknownError',
                        1   : 'XMLOutOfMemory',
                        2   : 'XMLFileUnreadable',
                        3   : 'XMLFileUnwritable',
                        4   : 'XMLFileOperationError',
                        5   : 'XMLNetworkAccessError',
                        101 : 'InternalXMLParserError',
                        102 : 'UnrecognizedXMLParserCode',
                        103 : 'XMLTranscoderError' }

# Fragments for the table used in the documentation for SBMLError.h.

doc_table_start_fragment = '''/**
 * @class doc_sbml_error_table
 *
 * @par
<table id="sbmlerror-table"
       class="text-table small-font alt-row-colors"
       width="95%" cellspacing="1" cellpadding="2" border="0">
 <tr style="background: lightgray" class="normal-font">
     <th valign="bottom"><strong>Enumerator</strong></th>
     <th valign="bottom"><strong>Meaning</strong></th>
     <th align="center" width="10">L1 V1</th>
     <th align="center" width="10">L1 V2</th>
     <th align="center" width="10">L2 V1</th>
     <th align="center" width="10">L2 V2</th>
     <th align="center" width="10">L2 V3</th>
     <th align="center" width="10">L2 V4</th>
     <th align="center" width="10">L3 V1</th>
     <th align="center" width="10">L3 V2</th>
 </tr>
'''

doc_table_end_fragment = '''</table>

*/
'''

# Templates and fragments used for the enum.

enum_start_fragment = '''/**
 * @enum SBMLErrorCode_t
 * Codes for all SBML-level errors and warnings from the core specification.
 *
 * @copydetails doc_sbml_error_code_ranges
 */
typedef enum
{
'''

enum_end_fragment = '''} SBMLErrorCode_t;
'''


# Templates and fragments used for the web page.

web_css_fragment = '''<style type='text/css'>
/*<![CDATA[*/
table {
  margin-bottom: 2em;
  border: 1px solid #ccc;
  border-spacing: 0;
}

td, th {
  border: none;
}

th {
  border-bottom: 1px solid #ccc;
}

td {
  border-bottom: 1px solid white;
}

tr:last-child > td {
  border-bottom: none;
}

td.s-fatal {
  font-size: 7pt;
  color: white;
  background-color: darkred;
  font-weight: bold;
  text-align: center;
  letter-spacing: -1px;
  padding: 2px;
}

td.s-fatal:before {
  content: "F";
}

td.s-error {
  font-size: 7pt;
  background-color: #dc143c;
  font-weight: bold;
  text-align: center;
  letter-spacing: -1px;
  padding: 2px;
}

td.s-error:before {
  content: "E";
}

td.s-warning {
  font-size: 7pt;
  background-color: gold;
  font-weight: bold;
  text-align: center;
  letter-spacing: -1px;
  padding: 2px;
}

td.s-warning:before {
  content: "W";
}

td.s-na {
  font-size: 7pt;
  font-weight: bold;
  text-align: center;
  letter-spacing: -1px;
  padding: 2px;
}

td.s-na:before {
  content: "NA";
}

tr.headers {
  background: lightgray;
}

th.levels {
  text-align: center;
  width: 1%;
  padding: 2px;
  letter-spacing: -1px;
}

th.errorid {
  width: 12ex;
  vertical-align: bottom;
}

th.errorid strong {
  color: #333;
}

td.code {
  font-size: 8pt;
  font-family: -webkit-monospace, monospace;
  color: #000;
  text-align: center;
  letter-spacing: -1px;
}

th.errorname {
  width: 20%;
}

td.errorname {
  font-size: 8pt;
  font-family: -webkit-monospace, monospace;
  color: #000;
  height: 26px;   /* to equalize heights of all table rows. */
}

th.meaning {
  font-size: 8pt;
  font-style: italic;
  vertical-align: bottom;
  letter-spacing: -1px;
}

th.meaning strong {
  color: #333;
}

td.meaning code {
  font-size: 8pt;
}

.s-warning
{
  background-color: gold;
  padding: .1em .5em;
  color: black;
}

.s-error
{
  background-color: #D23D24;
  padding: .1em .5em;
  color: white;
}

.s-fatal
{
  background-color: darkred;
  padding: .1em .5em;
  color: white;
}

.table-pkg-separator {
  text-align: center;
  background-color: #ffefd5;
  font-style: italic;
  font-weight: bold;
  line-height: 160%;
}
/*]]>*/
</style>
'''

web_toc_start_fragment = '''
<table style='margin-top: 2pt' id="toc" class="toc" summary="Contents">
<tr><td>
<div style="text-align:left">
<a name="TOC"/></a>
'''

web_toc_end_fragment = '''</div>
</td></tr>
</table>
'''

page_intro_template = '''
<p>This page lists all error, warning and informational diagnostic codes
and messages produced by <a
href="http://sbml.org/Software/libSBML">libSBML</a>, the software
underlying the <a
href="http://sbml.org/Facilities/Validator">Online SBML Validator</a>.
The diagnostics whose code numbers are
between 10000 and 90000 are defined in the <a
href="http://sbml.org/Documents/Specifications">SBML specification documents</a>;
the ones with numbers below 10000 and above 90000 are specific to libSBML or
this validation system and are not defined by the SBML specifications.  The
groups below provide finer-grained divisions in the diagnostics, for better
comprehensibility.</p>

<p>
In the tables below, the right-hand columns titled "L1V1", "L1V2", etc. refer
to Levels and Versions of the SBML specifications, and the entries in
each column refer to the severity of the condition in that
particular Level and Version of SBML.  The codes have the following
meanings:</p>
<p>
<table class="normal-font borderless-table gray-border sm-padding"
       width="200px" cellspacing="1" cellpadding="2" border="0"
       style="margin-left: 2em">
  <tr><th style="text-align: center">Symbol</th><th style="text-align: left">Meaning</th></tr>
  <tr><td class="s-warning gray-border"></td><td>Warning</td></tr>
  <tr><td class="s-error"></td><td>Error</td></tr>
  <tr><td class="s-fatal"></td><td>Fatal</td></tr>
  <tr><td class="s-na" style="border: none"></td><td>Not applicable</td></tr>
</table>
<p>For more information about the meanings of diagnostics numbered between
10000 and 90000, please consult the <a
href="http://sbml.org/Documents/Specifications">SBML specification documents</a>
relevant to the particularl Level and Version combination in question.</p>
'''

web_error_table_start_fragment = '''<center>
<table class="sm-padding sm-font alt-row-colors"
       width="100%" cellspacing="1" cellpadding="2" border="0">
  <tr class="headers">
    <th class="errorid">Error code</th>
    <th class="errorname">LibSBML name</th>
    <th class="errormeaning">Meaning</th>
    <th class="levels">L1 V1</th>
    <th class="levels">L1 V2</th>
    <th class="levels">L2 V1</th>
    <th class="levels">L2 V2</th>
    <th class="levels">L2 V3</th>
    <th class="levels">L2 V4</th>
    <th class="levels">L3 V1</th>
    <th class="levels">L3 V2</th>
  </tr>
'''

web_error_table_end_fragment = '''</table>
</center>
'''

error_groups = [["Internal",                       # HTML anchor
                 [LIBSBML_CAT_INTERNAL],           # category code(s)
                 "Internal errors",                # section title
'''This group of errors concerns problems involving the libSBML software
itself, or the underlying XML parser being used.  This almost certainly
indicates a software defect (i.e., bug) in libSBML.  <strong>Please
<a href='https://sourceforge.net/p/sbml/libsbml/new/'>report</a>
occurrences of these errors to the libSBML developers.</strong>'''
                 ],                                # section intro text

                ["OS",
                 [LIBSBML_CAT_SYSTEM],
                 "Operating system errors",
'''This group of diagnostic codes refers to problems that can be reported
by the operating system where libSBML is running.  This indicates something
that is not a libSBML error, but rather, is outside of the control of libSBML.'''
                 ],

                ["XML",
                 [LIBSBML_CAT_XML],
                 "XML errors",
'''This group of diagnostic codes refers to problems with the XML content of
the SBML file or data stream.  This usually arises from malformed XML, and is
detected at a very low level in the XML parsing system.  Further interpretation
of SBML is aborted if this type of error is encountered.'''
                 ],

                ["Overall-sbml",
                 [LIBSBML_CAT_SBML],
                 "Overall SBML conformance issues",
'''This group of diagnostic codes is concerned with general and overall issues
of conformance to the relevant SBML specifications.'''
                 ],

                ["General",
                 [LIBSBML_CAT_GENERAL_CONSISTENCY],
                 "General SBML consistency issues",
'''This group of diagnostic codes concerns the correct use of SBML constructs
according to the relevant SBML specifications.'''
                 ],

                ["Identifier",
                 [LIBSBML_CAT_IDENTIFIER_CONSISTENCY],
                 "SBML identifier consistency issues",
'''This group of diagnostic codes concerns general SBML issues related to
the identifiers used in SBML documents.  For convenience and greater control
during validation procedures, they are separated from the set of diagnostics 
for general SBML consistency.'''
                 ],

                ["Units",
                 [LIBSBML_CAT_UNITS_CONSISTENCY],
                 "Units consistency issues",
'''This group of diagnostic codes is concerned with the consistency of units
of measurement associated with quantities specified in an SBML model.  For
convenience and greater control during validation procedures, they are 
separated from the set of diagnostics for general SBML consistency.'''
                 ],

                ["MathML",
                 [LIBSBML_CAT_MATHML_CONSISTENCY],
                 "MathML issues",
'''This group of diagnostic codes concerns possible problems that can arise
with the MathML constructs used in an SBML document.'''
                 ],

                ["SBO",
                 [LIBSBML_CAT_SBO_CONSISTENCY],
                 "Systems Biology Ontology (SBO) issues",
'''This group of diagnostic codes concerns possible problems that can arise
with the MathML constructs used in an SBML document.  For
convenience and greater control during validation procedures, they are 
separated from the set of diagnostics for general SBML consistency.'''
                 ],

# The errors previously categorized as LIBSBML_CAT_OVERDETERMINED_MODEL in
# libSBML now seem to be categorized as general SBML spec consistency errors.
#
#                 ["Over",
#                  [LIBSBML_CAT_OVERDETERMINED_MODEL],
#                  "Overdetermined models",
# '''This group of diagnostic codes is concerned with problems encountered
# while testing for overdetermined models; that is, a model where the system is
# overdetermined, therefore violating a tenet of proper SBML.'''
#                  ],

                ["Practice",
                 [LIBSBML_CAT_MODELING_PRACTICE],
                 "Modeling practice issues",
'''This group of diagnostic codes is concerned with matters of good modeling
practices involving SBML and computational modeling.  These are tests
performed by libSBML and do not have equivalent SBML validation rules.
For convenience and greater control during validation procedures, they are
separated from the set of diagnostics for general SBML consistency.'''
                 ],

                ["Internal-consistency",
                 [LIBSBML_CAT_INTERNAL_CONSISTENCY],
                 "Internal SBML consistency issues",
'''This set of diagnostics is concerned with problems that can occur while
validating the libSBML internal representation of SBML constructs. These
are tests performed by libSBML and do not have equivalent SBML validation
rules.  For convenience and greater control during validation procedures, they
are separated from the set of diagnostics for general SBML consistency.'''
                 ],

# 2014-05-14: We decided not to show the conversion codes in the online table.
#
#                 ["conversion",
#                  [LIBSBML_CAT_SBML_L1_COMPAT,
#                   LIBSBML_CAT_SBML_L2V1_COMPAT,
#                   LIBSBML_CAT_SBML_L2V1_COMPAT,
#                   LIBSBML_CAT_SBML_L2V2_COMPAT,
#                   LIBSBML_CAT_SBML_L2V3_COMPAT,
#                   LIBSBML_CAT_SBML_L2V4_COMPAT,
#                   LIBSBML_CAT_SBML_L3V1_COMPAT],
#                  "Problems in converting models",
# '''This group of diagnostic codes is concerned with problems encountered
# during conversion of an SBML document from one SBML Level+Version combination
# to another.'''
#                 ],

]

# -----------------------------------------------------------------------------
# Main code for --doc.
# -----------------------------------------------------------------------------

def write_doc(stream, module):
  stream.write(doc_table_start_fragment)
  for errNum in sorted(get_numeric_constants(module) - ignored_error_codes):
    stream.write(make_doc_row_text(errNum, module))
  stream.write(doc_table_end_fragment)


def make_doc_row_text(errNum, module):
  s = get_symbol(module, errNum)
  output  = '<tr>'
  output += '<td class="code">@sbmlconstant{' + s + ', SBMLErrorCode_t}</td>\n'
  if errNum < 99999:
    e = SBMLError(errNum, 1, 1)
    if not e.isValid():
      return ''
    output += '<td class="meaning">{}</td>\n'.format(to_html(e.getShortMessage()))
    for lv in sbml_levels_versions:
      e = SBMLError(errNum, lv[0], lv[1])
      output += '<td class="{}"></td>\n'.format(get_severity_class(e.getSeverity()))
  else:
    for package in package_codes:
      pkg_name  = package[0]
      pkg_start = package[1]
      pkg_end   = pkg_start + 1000000
      if errNum > pkg_start and errNum < pkg_end:
        # Packages are only possible in SBML Level 3.
        # Check existence in some L/V combination.
        elist = []
        for lv in sbml_levels_versions:
          if lv[0] < 3:
            continue
          elist.append(SBMLError(errNum, lv[0], lv[1], '', 0, 0, 0, 0, pkg_name, 1))
        if all(not e.isValid() for e in elist):
          return ''
        first_e = next(e for e in elist if e.isValid())
        output += '<td class="meaning">{}</td>\n'.format(to_html(first_e.getShortMessage()))
        for lv in sbml_levels_versions:
          if lv[0] < 3:
            output += '<td class="{}"></td>\n'.format(get_severity_class(0))
            continue
          e = SBMLError(errNum, lv[0], lv[1], '', 0, 0, 0, 0, pkg_name, 1)
          output += '<td class="{}"></td>\n'.format(get_severity_class(e.getSeverity()))
        break

  output += '</tr>\n'
  print_progress()
  return output


# -----------------------------------------------------------------------------
# Main code for --web.
# -----------------------------------------------------------------------------

def write_web(stream, module):
  stream.write(web_css_fragment)
  stream.write(make_web_toc())
  stream.write(page_intro_template.format(LIBSBML_DOTTED_VERSION))
  for entry in error_groups:
    anchor     = entry[0]
    categories = entry[1]
    title      = entry[2]
    intro      = entry[3]

    stream.write('<a name="{}"><h3>{}</h3></a>\n'.format(anchor, title))
    stream.write('<p>' + intro + '</p>\n')
    stream.write(web_error_table_start_fragment)
    for errNum in sorted(get_numeric_constants(module, 0, 100000) - ignored_error_codes):
      e = SBMLError(errNum, 1, 1)
      if not e.isValid():
        continue
      if not e.getCategory() in categories:
        continue
      stream.write(make_web_row_text(errNum, module))

    for package in package_codes:
      pkg_name  = package[0]
      pkg_start = package[1]
      pkg_end   = pkg_start + 1000000
      printed_separator = False
      for errNum in sorted(get_numeric_constants(module, pkg_start, pkg_end)):
        e = SBMLError(errNum, 3, 1, '', 0, 0, 0, 0, pkg_name, 1)
        msg = e.getShortMessage()
        if not msg:
          continue
        if not e.getCategory() in categories:
          continue
        if not printed_separator:
          stream.write(make_web_table_pkg_separator(pkg_name))
          printed_separator = True
        stream.write(make_web_row_pkg_text(e, errNum, pkg_name, pkg_start, module))

    print_progress("Writing '" + title + "' \n")
    stream.write(web_error_table_end_fragment)


def make_web_toc():
  output = web_toc_start_fragment
  for entry in error_groups:
    anchor  = entry[0]
    title   = entry[2]
    output += '<a href="#{}">{}</a><br/>\n'.format(anchor, title)
  output += web_toc_end_fragment
  return output


def make_web_table_pkg_separator(pkg_name):
  return '<tr><td colspan="' + str(3 + len(sbml_levels_versions)) \
    + '" class="table-pkg-separator">Codes for SBML Level 3 package "' \
    + pkg_name + '"</td></tr>'


def make_web_row_text(errNum, module):
  e = SBMLError(errNum, 1, 1)
  if not e.isValid():
    return ''

  output  = '<tr>'
  output += '<td class="code">{0:05d}</td>'.format(errNum)
  output += '<td class="errorname">{}</td>'.format(get_symbol(module, errNum))
  output += '<td class="meaning">{}</td>'.format(to_html(e.getShortMessage()))
  for lv in sbml_levels_versions:
    e = SBMLError(errNum, lv[0], lv[1])
    severity = e.getSeverity()
    output += '<td class="{}"></td>'.format(get_severity_class(severity))
  output += '</tr>\n'
  return output


def make_web_row_pkg_text(err, errNum, pkg_name, pkg_start, module):
  output  = '<tr>'
  output += '<td class="code">{0}-{1:05d}</td>'.format(pkg_name, errNum-pkg_start)
  output += '<td class="errorname">{}</td>'.format(get_symbol(module, errNum))
  output += '<td class="meaning">{}</td>'.format(to_html(err.getShortMessage()))
  for lv in range(0, len(sbml_levels_versions) - 1):
    output += '<td class="{}"></td>'.format(get_severity_class(0))
  output += '<td class="{}"></td>'.format(get_severity_class(err.getSeverity()))
  output += '</tr>\n'
  return output


# -----------------------------------------------------------------------------
# Main code for --enum.
# -----------------------------------------------------------------------------

def write_enum(stream, module):
  stream.write(enum_start_fragment)
  for errNum in sorted(get_numeric_constants(module, 0, 100000)):
    e = SBMLError(errNum, 1, 1)
    if e.isValid():
      if errNum == 10000:
        stream.write("  ")
      else:
        stream.write(", ")
      stream.write("%s = %s" %(ljust(get_symbol(module, errNum), 37), str(errNum)))
      msg = e.getShortMessage()
      if msg != '':
        if msg[-1] != '.':
          maybe_period = '.'
        else:
          maybe_period = ''
        stream.write(" /*!< " + to_html(msg) + maybe_period + " */")
      stream.write("\n")
      print_progress()

  stream.write(enum_end_fragment)


# -----------------------------------------------------------------------------
# Helper functions.
# -----------------------------------------------------------------------------

def get_module():
  fp, pathname, description = find_module("libsbml")
  return load_module('_libsbml', fp, pathname, description)


def get_numeric_constants(module, low=0, high=90000000):
  constants = set()
  for symbol in dir(module):
    try:                                # Some symbols don't have a value,
      value = eval(symbol)              # so we have to guard against that.
      if isinstance(value, int) and low <= value and value <= high:
          constants.add(value)
    except:
      continue
  return constants


def get_symbol(module, number):
  # This is an inefficient way of getting the string corresponding to a
  # given error number, but we don't care because this application isn't
  # performance-critical.  The algorithm is also fragile, but if we're
  # careful about the range of values attempted (i.e., numbers from 10000
  # to 100000), it should be okay.  Unfortunately, values below 100 hits
  # a number of small enumerations in libSBML, so we have to special-case
  # that.  Really, this whole thing is just awful.
  #
  if number in low_numbered_errors.keys():
    return low_numbered_errors[number]

  symbols = dir(module)
  attributes = [None]*len(symbols)
  for i in range(0, len(symbols)):
    attributes[i] = getattr(module, symbols[i])
  for i in range(0, len(symbols)):
    if isinstance(attributes[i], int) == True and attributes[i] == number:
      return symbols[i]


def get_severity_class(severity):
  if   (severity == 3): return "s-fatal"
  elif (severity == 2): return "s-error"
  elif (severity == 1): return "s-warning"
  else:                 return "s-na"


def to_html(text):
  text = text.replace('<', '&lt;')
  text = text.replace('>', '&gt;')
  text = text.replace('&lt;', '<code>&lt;')
  text = text.replace('&gt;', '&gt;</code>')
  return text


def print_progress(marker="."):
  # Echo to terminal to show progress.
  sys.stdout.write(marker)
  sys.stdout.flush()


# -----------------------------------------------------------------------------
# Main.
# -----------------------------------------------------------------------------

def main (args):
  """Usage:
            writeErrorTable.py [--doc | --enum | --web]  OUTPUTFILE

  The first argument must one of --doc, --enum or --web.

  * Given --doc, it will generate a table suitable for use in the libSBML
    API documentation as it appears in the header of SBMLError.h.

  * Given --enum, it will generate the SBMLErrorCode_t enum for SBMLError.h.

  * Given --web, it will generate output used in the table in the web page at
    http://sbml.org/Facilities/Documentation/Error_Categories.

  It will write its output to OUTPUTFILE.  Note that the name of the file
  will be used as given; no file name extension will be added.  Callers are
  assumed to supply the full name desired.
  """

  # Start with some sanity-checking.

  if len(args) != 3 or (args[1] not in ['--doc', '--enum', '--web']):
    print(main.__doc__)
    sys.exit(1)

  # OK, let's do this thing.

  module = get_module()

  print('Writing output to ' + args[2])
  stream = open(args[2], 'w')

  if args[1] == '--doc':
    write_doc(stream, module)
  elif args[1] == '--enum':
    write_enum(stream, module)
  else:
    write_web(stream, module)

  stream.close()
  print 'Done.'



if __name__ == '__main__':
  main(sys.argv)



#!/usr/bin/env python

import unittest
import rewrite_pydoc

class TestArgs(unittest.TestCase):

    def test_input_file_arg(self):
        args  = rewrite_pydoc.parse_cmdline(['-f', 'foo.bar', '-o', 'ignored.bar'])
        fname = rewrite_pydoc.get_input_file_name(args)
        self.assertEqual(fname, 'foo.bar')

    def test_output_file_arg(self):
        args  = rewrite_pydoc.parse_cmdline(['-f', 'ignored.bar', '-o', 'output.zap'])
        fname = rewrite_pydoc.get_output_file_name(args)
        self.assertEqual(fname, 'output.zap')

    def test_inclue_arg(self):
        args    = rewrite_pydoc.parse_cmdline(['-f', 'ignored.bar', '-o', 'output.zap', '-i', 'foo'])
        dirname = rewrite_pydoc.get_include_dir(args)
        self.assertEqual(dirname, 'foo')

    def test_graphics_arg(self):
        args    = rewrite_pydoc.parse_cmdline(['-f', 'ignored.bar', '-o', 'output.zap', '-g', 'foo'])
        dirname = rewrite_pydoc.get_graphics_dir(args)
        self.assertEqual(dirname, 'foo')


def main():
    unittest.main()

if __name__ == '__main__':
    main()



#!/usr/bin/env python
##
## @file    run.py
## @brief   Unit test runner for libSBML Python doc converter
## @author  Mike Hucka
## 
## <!--------------------------------------------------------------------------
## This file is part of libSBML.  Please visit http://sbml.org for more
## information about SBML, and the latest version of libSBML.
##
## Copyright (C) 2013-2018 jointly by the following organizations:
##     1. California Institute of Technology, Pasadena, CA, USA
##     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
##     3. University of Heidelberg, Heidelberg, Germany
##
## Copyright (C) 2009-2013 jointly by the following organizations: 
##     1. California Institute of Technology, Pasadena, CA, USA
##     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
##  
## Copyright (C) 2006-2008 by the California Institute of Technology,
##     Pasadena, CA, USA 
##  
## Copyright (C) 2002-2005 jointly by the following organizations: 
##     1. California Institute of Technology, Pasadena, CA, USA
##     2. Japan Science and Technology Agency, Japan
## 
## This library is free software; you can redistribute it and/or modify it
## under the terms of the GNU Lesser General Public License as published by
## the Free Software Foundation.  A copy of the license agreement is provided
## in the file named "LICENSE.txt" included with this software distribution
## and also available online as http://sbml.org/software/libsbml/license.html
## ------------------------------------------------------------------------ -->

import argparse
import os
import sys
import unittest

# Configure command line arguments and process them.
# If -h is provided, argparse will print the help and automatically exit.

help_prolog = "Run tests for libSBML's Python document string converter."
help_epilog = '''If give no arguments, this will run all the unit tests in 
the "cases" subdirectory..'''

parser = argparse.ArgumentParser(description=help_prolog, epilog=help_epilog)
parser.parse_args()

# Run the tests.

ourdir = os.path.dirname(os.path.abspath(__file__))
tests  = unittest.TestLoader().discover(start_dir=(ourdir + '/cases'))
runner = unittest.runner.TextTestRunner()
runner.run(tests)



#!/usr/bin/env python

import sys

def convertOboFile(oboFile, outputFile): 
  term   = -1
  parent = -1
  stream = open(oboFile)
  output = open(outputFile, "w")
  
  for line in stream.readlines():
    try:
      if line.startswith("id:"):
        term = int( line[8:15] )
      elif line.startswith("is_a:"):
        parent = int( line[10:17] )
        output.write( "  mParent.insert( pair<const int, int>(%3d, %3d) );\n" % (term, parent))
      elif line.startswith("is_obsolete:"):
        parent = 1000
        output.write( "  mParent.insert( pair<const int, int>(%3d, %4d) );\n" % (term, parent))
    except ValueError:
      pass
  
  stream.close()
  output.close()


if __name__ == '__main__':
  if len(sys.argv) != 3:
    convertOboFile('sbo-obo-flat.txt', 'output.txt')
  else: 
    convertOboFile(sys.argv[1], sys.argv[2])



#!/usr/bin/env python

import unittest
import rewrite_pydoc

class TestRead(unittest.TestCase):

    def test_file_read(self):
        args  = rewrite_pydoc.parse_cmdline(['-f', 'test/data/001.i', '-o', 'ignored.bar'])
        fname = rewrite_pydoc.get_input_file_name(args)
        contents = rewrite_pydoc.read_file_contents(fname)
        self.assertEqual(contents, 'The contents.\n')



def main():
    unittest.main()

if __name__ == '__main__':
    main()



#
# @file    TestXMLNode_newSetters.py
# @brief   XMLNode unit tests
#
# @author  Akiya Jouraku (Python conversion)
# @author  Sarah Keating 
# 
# ====== WARNING ===== WARNING ===== WARNING ===== WARNING ===== WARNING ======
#
# DO NOT EDIT THIS FILE.
#
# This file was generated automatically by converting the file located at
# src/xml/test/TestXMLNode_newSetters.c
# using the conversion program dev/utilities/translateTests/translateTests.pl.
# Any changes made here will be lost the next time the file is regenerated.
#
# -----------------------------------------------------------------------------
# This file is part of libSBML.  Please visit http://sbml.org for more
# information about SBML, and the latest version of libSBML.
#
# Copyright 2005-2010 California Institute of Technology.
# Copyright 2002-2005 California Institute of Technology and
#                     Japan Science and Technology Corporation.
# 
# This library is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation.  A copy of the license agreement is provided
# in the file named "LICENSE.txt" included with this software distribution
# and also available online as http://sbml.org/software/libsbml/license.html
# -----------------------------------------------------------------------------

import sys
import unittest
import libsbml


class TestXMLNode_newSetters(unittest.TestCase):


  def test_XMLNode_addChild1(self):
    node = libsbml.XMLNode()
    node2 = libsbml.XMLNode()
    i = node.addChild(node2)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( node.getNumChildren() == 1 )
    _dummyList = [ node ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ node2 ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_XMLNode_addChild2(self):
    triple = libsbml.XMLTriple("test","","")
    attr = libsbml.XMLAttributes()
    node = libsbml.XMLNode(triple,attr)
    node2 = libsbml.XMLNode()
    i = node.addChild(node2)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( node.getNumChildren() == 1 )
    _dummyList = [ triple ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ attr ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ node ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ node2 ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_XMLNode_addChild3(self):
    triple = libsbml.XMLTriple("test","","")
    node = libsbml.XMLNode(triple)
    node2 = libsbml.XMLNode()
    i = node.addChild(node2)
    self.assertTrue( i == libsbml.LIBSBML_INVALID_XML_OPERATION )
    self.assertTrue( node.getNumChildren() == 0 )
    _dummyList = [ triple ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ node ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ node2 ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_XMLNode_clearAttributes(self):
    triple = libsbml.XMLTriple("test","","")
    attr = libsbml.XMLAttributes()
    node = libsbml.XMLNode(triple,attr)
    xt2 = libsbml.XMLTriple("name3", "http://name3.org/", "p3")
    xt1 = libsbml.XMLTriple("name5", "http://name5.org/", "p5")
    i = node.addAttr( "name1", "val1")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( node.getAttributes().getLength() == 1 )
    i = node.addAttr( "name2", "val2", "http://name1.org/", "p1")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( node.getAttributes().getLength() == 2 )
    i = node.addAttr(xt2, "val2")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( node.getAttributes().getLength() == 3 )
    i = node.addAttr( "name4", "val4")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( node.getAttributes().getLength() == 4 )
    i = node.clearAttributes()
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( node.getAttributes().getLength() == 0 )
    _dummyList = [ xt1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ xt2 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ triple ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ attr ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ node ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_XMLNode_clearNamespaces(self):
    triple = libsbml.XMLTriple("test","","")
    attr = libsbml.XMLAttributes()
    node = libsbml.XMLNode(triple,attr)
    i = node.addNamespace( "http://test1.org/", "test1")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    nms = node.getNamespaces()
    self.assertTrue( nms.getLength() == 1 )
    i = node.addNamespace( "http://test2.org/", "test2")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    nms = node.getNamespaces()
    self.assertTrue( nms.getLength() == 2 )
    i = node.clearNamespaces()
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    nms = node.getNamespaces()
    self.assertTrue( nms.getLength() == 0 )
    _dummyList = [ triple ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ attr ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ node ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_XMLNode_removeAttributes(self):
    triple = libsbml.XMLTriple("test","","")
    attr = libsbml.XMLAttributes()
    node = libsbml.XMLNode(triple,attr)
    xt2 = libsbml.XMLTriple("name3", "http://name3.org/", "p3")
    xt1 = libsbml.XMLTriple("name5", "http://name5.org/", "p5")
    i = node.addAttr( "name1", "val1")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( node.getAttributes().getLength() == 1 )
    i = node.addAttr( "name2", "val2", "http://name1.org/", "p1")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( node.getAttributes().getLength() == 2 )
    i = node.addAttr(xt2, "val2")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( node.getAttributes().getLength() == 3 )
    i = node.addAttr( "name4", "val4")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( node.getAttributes().getLength() == 4 )
    i = node.removeAttr(7)
    self.assertTrue( i == libsbml.LIBSBML_INDEX_EXCEEDS_SIZE )
    i = node.removeAttr( "name7")
    self.assertTrue( i == libsbml.LIBSBML_INDEX_EXCEEDS_SIZE )
    i = node.removeAttr( "name7", "namespaces7")
    self.assertTrue( i == libsbml.LIBSBML_INDEX_EXCEEDS_SIZE )
    i = node.removeAttr(xt1)
    self.assertTrue( i == libsbml.LIBSBML_INDEX_EXCEEDS_SIZE )
    self.assertTrue( node.getAttributes().getLength() == 4 )
    i = node.removeAttr(3)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( node.getAttributes().getLength() == 3 )
    i = node.removeAttr( "name1")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( node.getAttributes().getLength() == 2 )
    i = node.removeAttr( "name2", "http://name1.org/")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( node.getAttributes().getLength() == 1 )
    i = node.removeAttr(xt2)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( node.getAttributes().getLength() == 0 )
    _dummyList = [ xt1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ xt2 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ triple ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ attr ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ node ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_XMLNode_removeChildren(self):
    node = libsbml.XMLNode()
    node2 = libsbml.XMLNode()
    node3 = libsbml.XMLNode()
    node.addChild(node2)
    node.addChild(node3)
    self.assertTrue( node.getNumChildren() == 2 )
    i = node.removeChildren()
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( node.getNumChildren() == 0 )
    _dummyList = [ node ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ node2 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ node3 ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_XMLNode_removeNamespaces(self):
    triple = libsbml.XMLTriple("test","","")
    attr = libsbml.XMLAttributes()
    node = libsbml.XMLNode(triple,attr)
    i = node.addNamespace( "http://test1.org/", "test1")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    nms = node.getNamespaces()
    self.assertTrue( nms.getLength() == 1 )
    i = node.addNamespace( "http://test2.org/", "test2")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    nms = node.getNamespaces()
    self.assertTrue( nms.getLength() == 2 )
    i = node.removeNamespace(7)
    self.assertTrue( i == libsbml.LIBSBML_INDEX_EXCEEDS_SIZE )
    nms = node.getNamespaces()
    self.assertTrue( nms.getLength() == 2 )
    i = node.removeNamespace( "name7")
    self.assertTrue( i == libsbml.LIBSBML_INDEX_EXCEEDS_SIZE )
    nms = node.getNamespaces()
    self.assertTrue( nms.getLength() == 2 )
    i = node.removeNamespace(0)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    nms = node.getNamespaces()
    self.assertTrue( nms.getLength() == 1 )
    i = node.removeNamespace( "test2")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    nms = node.getNamespaces()
    self.assertTrue( nms.getLength() == 0 )
    _dummyList = [ triple ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ attr ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ node ]; _dummyList[:] = []; del _dummyList
    pass  

def suite():
  suite = unittest.TestSuite()
  suite.addTest(unittest.makeSuite(TestXMLNode_newSetters))

  return suite

if __name__ == "__main__":
  if unittest.TextTestRunner(verbosity=1).run(suite()).wasSuccessful() :
    sys.exit(0)
  else:
    sys.exit(1)



#
# @file    TestReaction_newSetters.py
# @brief   Reaction unit tests for new set function API
#
# @author  Akiya Jouraku (Python conversion)
# @author  Sarah Keating 
# 
# ====== WARNING ===== WARNING ===== WARNING ===== WARNING ===== WARNING ======
#
# DO NOT EDIT THIS FILE.
#
# This file was generated automatically by converting the file located at
# src/sbml/test/TestReaction_newSetters.c
# using the conversion program dev/utilities/translateTests/translateTests.pl.
# Any changes made here will be lost the next time the file is regenerated.
#
# -----------------------------------------------------------------------------
# This file is part of libSBML.  Please visit http://sbml.org for more
# information about SBML, and the latest version of libSBML.
#
# Copyright 2005-2010 California Institute of Technology.
# Copyright 2002-2005 California Institute of Technology and
#                     Japan Science and Technology Corporation.
# 
# This library is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation.  A copy of the license agreement is provided
# in the file named "LICENSE.txt" included with this software distribution
# and also available online as http://sbml.org/software/libsbml/license.html
# -----------------------------------------------------------------------------

import sys
import unittest
import libsbml


class TestReaction_newSetters(unittest.TestCase):

  global R
  R = None

  def setUp(self):
    self.R = libsbml.Reaction(1,2)
    if (self.R == None):
      pass    
    pass  

  def tearDown(self):
    _dummyList = [ self.R ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Reaction_addProduct1(self):
    m = libsbml.Reaction(2,2)
    p = libsbml.SpeciesReference(2,2)
    p1 = libsbml.SpeciesReference(2,2)
    p1.setSpecies( "k")
    p1.setId( "k1")
    i = m.addProduct(p)
    self.assertTrue( i == libsbml.LIBSBML_INVALID_OBJECT )
    p.setSpecies( "k")
    p.setId( "k1")
    i = m.addProduct(p)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( m.getNumProducts() == 1 )
    i = m.addProduct(p1)
    self.assertTrue( i == libsbml.LIBSBML_DUPLICATE_OBJECT_ID )
    self.assertTrue( m.getNumProducts() == 1 )
    _dummyList = [ p ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ p1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Reaction_addProduct2(self):
    m = libsbml.Reaction(2,2)
    p = libsbml.SpeciesReference(2,1)
    p.setSpecies( "k")
    i = m.addProduct(p)
    self.assertTrue( i == libsbml.LIBSBML_VERSION_MISMATCH )
    self.assertTrue( m.getNumProducts() == 0 )
    _dummyList = [ p ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Reaction_addProduct3(self):
    m = libsbml.Reaction(2,2)
    p = libsbml.SpeciesReference(1,2)
    p.setSpecies( "k")
    i = m.addProduct(p)
    self.assertTrue( i == libsbml.LIBSBML_LEVEL_MISMATCH )
    self.assertTrue( m.getNumProducts() == 0 )
    _dummyList = [ p ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Reaction_addProduct4(self):
    m = libsbml.Reaction(2,2)
    p = None
    i = m.addProduct(p)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_FAILED )
    self.assertTrue( m.getNumProducts() == 0 )
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Reaction_addReactant1(self):
    m = libsbml.Reaction(2,2)
    p = libsbml.SpeciesReference(2,2)
    p1 = libsbml.SpeciesReference(2,2)
    p1.setSpecies( "k")
    p1.setId( "k1")
    i = m.addReactant(p)
    self.assertTrue( i == libsbml.LIBSBML_INVALID_OBJECT )
    p.setSpecies( "k")
    p.setId( "k1")
    i = m.addReactant(p)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( m.getNumReactants() == 1 )
    i = m.addReactant(p1)
    self.assertTrue( i == libsbml.LIBSBML_DUPLICATE_OBJECT_ID )
    self.assertTrue( m.getNumReactants() == 1 )
    _dummyList = [ p1 ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ p ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Reaction_addReactant2(self):
    m = libsbml.Reaction(2,2)
    p = libsbml.SpeciesReference(2,1)
    p.setSpecies( "k")
    i = m.addReactant(p)
    self.assertTrue( i == libsbml.LIBSBML_VERSION_MISMATCH )
    self.assertTrue( m.getNumReactants() == 0 )
    _dummyList = [ p ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Reaction_addReactant3(self):
    m = libsbml.Reaction(2,2)
    p = libsbml.SpeciesReference(1,2)
    p.setSpecies( "k")
    i = m.addReactant(p)
    self.assertTrue( i == libsbml.LIBSBML_LEVEL_MISMATCH )
    self.assertTrue( m.getNumReactants() == 0 )
    _dummyList = [ p ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Reaction_addReactant4(self):
    m = libsbml.Reaction(2,2)
    p = None
    i = m.addReactant(p)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_FAILED )
    self.assertTrue( m.getNumReactants() == 0 )
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Reaction_createKineticLaw(self):
    r = libsbml.Reaction(2,2)
    kl = r.createKineticLaw()
    self.assertTrue( r.isSetKineticLaw() == True )
    self.assertTrue( (kl).getLevel() == 2 )
    self.assertTrue( (kl).getVersion() == 2 )
    _dummyList = [ r ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Reaction_createProduct(self):
    m = libsbml.Reaction(2,2)
    p = m.createProduct()
    self.assertTrue( m.getNumProducts() == 1 )
    self.assertTrue( (p).getLevel() == 2 )
    self.assertTrue( (p).getVersion() == 2 )
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Reaction_createReactant(self):
    m = libsbml.Reaction(2,2)
    p = m.createReactant()
    self.assertTrue( m.getNumReactants() == 1 )
    self.assertTrue( (p).getLevel() == 2 )
    self.assertTrue( (p).getVersion() == 2 )
    _dummyList = [ m ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Reaction_setFast1(self):
    i = self.R.setFast(True)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( self.R.getFast() == True )
    self.assertEqual( True, self.R.isSetFast() )
    i = self.R.setFast(False)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( self.R.getFast() == False )
    self.assertEqual( True, self.R.isSetFast() )
    i = self.R.unsetFast()
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( self.R.getFast() == False )
    self.assertEqual( False, self.R.isSetFast() )
    pass  

  def test_Reaction_setFast2(self):
    R1 = libsbml.Reaction(2,4)
    i = R1.unsetFast()
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( R1.getFast() == False )
    self.assertEqual( False, R1.isSetFast() )
    pass  

  def test_Reaction_setId1(self):
    i = self.R.setId( "1cell")
    self.assertTrue( i == libsbml.LIBSBML_INVALID_ATTRIBUTE_VALUE )
    self.assertEqual( False, self.R.isSetId() )
    pass  

  def test_Reaction_setId2(self):
    i = self.R.setId( "cell")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( True, self.R.isSetId() )
    self.assertTrue((  "cell"  == self.R.getId() ))
    i = self.R.setId("")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( False, self.R.isSetId() )
    pass  

  def test_Reaction_setKineticLaw1(self):
    kl = libsbml.KineticLaw(2,1)
    kl.setMath(libsbml.parseFormula("1"))
    i = self.R.setKineticLaw(kl)
    self.assertTrue( i == libsbml.LIBSBML_LEVEL_MISMATCH )
    self.assertEqual( False, self.R.isSetKineticLaw() )
    _dummyList = [ kl ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Reaction_setKineticLaw2(self):
    kl = libsbml.KineticLaw(1,1)
    kl.setMath(libsbml.parseFormula("1"))
    i = self.R.setKineticLaw(kl)
    self.assertTrue( i == libsbml.LIBSBML_VERSION_MISMATCH )
    self.assertEqual( False, self.R.isSetKineticLaw() )
    _dummyList = [ kl ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Reaction_setKineticLaw3(self):
    kl = libsbml.KineticLaw(1,2)
    kl.setMath(libsbml.parseFormula("1"))
    i = self.R.setKineticLaw(kl)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( True, self.R.isSetKineticLaw() )
    _dummyList = [ kl ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Reaction_setKineticLaw4(self):
    i = self.R.setKineticLaw(None)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( False, self.R.isSetKineticLaw() )
    i = self.R.unsetKineticLaw()
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( False, self.R.isSetKineticLaw() )
    pass  

  def test_Reaction_setName1(self):
    i = self.R.setName( "cell")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( True, self.R.isSetName() )
    i = self.R.unsetName()
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( False, self.R.isSetName() )
    pass  

  def test_Reaction_setName2(self):
    p = libsbml.Reaction(2,2)
    i = p.setName( "1cell")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( True, p.isSetName() )
    i = p.unsetName()
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( False, p.isSetName() )
    _dummyList = [ p ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Reaction_setName3(self):
    p = libsbml.Reaction(2,2)
    i = p.setName("")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertEqual( False, p.isSetName() )
    _dummyList = [ p ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Reaction_setReversible1(self):
    i = self.R.setReversible(True)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( self.R.getReversible() == True )
    i = self.R.setReversible(False)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( self.R.getReversible() == False )
    pass  

def suite():
  suite = unittest.TestSuite()
  suite.addTest(unittest.makeSuite(TestReaction_newSetters))

  return suite

if __name__ == "__main__":
  if unittest.TextTestRunner(verbosity=1).run(suite()).wasSuccessful() :
    sys.exit(0)
  else:
    sys.exit(1)




#
# @file    TestDate_newSetters.py
# @brief   Date unit tests
#
# @author  Akiya Jouraku (Python conversion)
# @author  Sarah Keating 
# 
# ====== WARNING ===== WARNING ===== WARNING ===== WARNING ===== WARNING ======
#
# DO NOT EDIT THIS FILE.
#
# This file was generated automatically by converting the file located at
# src/annotation/test/TestDate_newSetters.c
# using the conversion program dev/utilities/translateTests/translateTests.pl.
# Any changes made here will be lost the next time the file is regenerated.
#
# -----------------------------------------------------------------------------
# This file is part of libSBML.  Please visit http://sbml.org for more
# information about SBML, and the latest version of libSBML.
#
# Copyright 2005-2010 California Institute of Technology.
# Copyright 2002-2005 California Institute of Technology and
#                     Japan Science and Technology Corporation.
# 
# This library is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation.  A copy of the license agreement is provided
# in the file named "LICENSE.txt" included with this software distribution
# and also available online as http://sbml.org/software/libsbml/license.html
# -----------------------------------------------------------------------------

import sys
import unittest
import libsbml


class TestDate_newSetters(unittest.TestCase):


  def test_Date_setDateAsString(self):
    date = libsbml.Date(2007,10,23,14,15,16,1,3,0)
    self.assertTrue( date != None )
    i = date.setDateAsString( "20081-12-30T12:15:45+02:00")
    self.assertTrue( i == libsbml.LIBSBML_INVALID_ATTRIBUTE_VALUE )
    self.assertTrue((                                 "2007-10-23T14:15:16+03:00" == date.getDateAsString() ))
    i = date.setDateAsString( "200-12-30T12:15:45+02:00")
    self.assertTrue( i == libsbml.LIBSBML_INVALID_ATTRIBUTE_VALUE )
    self.assertTrue((                                 "2007-10-23T14:15:16+03:00" == date.getDateAsString() ))
    i = date.setDateAsString("")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue((                             "2000-01-01T00:00:00Z" == date.getDateAsString() ))
    i = date.setDateAsString( "2008-12-30T12:15:45+02:00")
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( date.getYear() == 2008 )
    self.assertTrue( date.getMonth() == 12 )
    self.assertTrue( date.getDay() == 30 )
    self.assertTrue( date.getHour() == 12 )
    self.assertTrue( date.getMinute() == 15 )
    self.assertTrue( date.getSecond() == 45 )
    self.assertTrue( date.getSignOffset() == 1 )
    self.assertTrue( date.getHoursOffset() == 2 )
    self.assertTrue( date.getMinutesOffset() == 0 )
    _dummyList = [ date ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Date_setDay(self):
    date = libsbml.Date(2005,2,12,12,15,45,1,2,0)
    self.assertTrue( date != None )
    i = date.setDay(29)
    self.assertTrue( i == libsbml.LIBSBML_INVALID_ATTRIBUTE_VALUE )
    self.assertTrue( date.getDay() == 1 )
    i = date.setDay(31)
    self.assertTrue( i == libsbml.LIBSBML_INVALID_ATTRIBUTE_VALUE )
    self.assertTrue( date.getDay() == 1 )
    i = date.setDay(15)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( date.getDay() == 15 )
    self.assertTrue((                             "2005-02-15T12:15:45+02:00" == date.getDateAsString() ))
    _dummyList = [ date ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Date_setHour(self):
    date = libsbml.Date(2005,12,30,12,15,45,1,2,0)
    self.assertTrue( date != None )
    i = date.setHour(434)
    self.assertTrue( i == libsbml.LIBSBML_INVALID_ATTRIBUTE_VALUE )
    self.assertTrue( date.getHour() == 0 )
    i = date.setHour(12121)
    self.assertTrue( i == libsbml.LIBSBML_INVALID_ATTRIBUTE_VALUE )
    self.assertTrue( date.getHour() == 0 )
    i = date.setHour(9)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( date.getHour() == 9 )
    self.assertTrue((                             "2005-12-30T09:15:45+02:00" == date.getDateAsString() ))
    _dummyList = [ date ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Date_setHoursOffset(self):
    date = libsbml.Date(2005,12,30,12,15,45,1,2,0)
    self.assertTrue( date != None )
    i = date.setHoursOffset(434)
    self.assertTrue( i == libsbml.LIBSBML_INVALID_ATTRIBUTE_VALUE )
    self.assertTrue( date.getHoursOffset() == 0 )
    i = date.setHoursOffset(11)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( date.getHoursOffset() == 11 )
    self.assertTrue((                             "2005-12-30T12:15:45+11:00" == date.getDateAsString() ))
    _dummyList = [ date ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Date_setMinute(self):
    date = libsbml.Date(2005,12,30,12,15,45,1,2,0)
    self.assertTrue( date != None )
    i = date.setMinute(434)
    self.assertTrue( i == libsbml.LIBSBML_INVALID_ATTRIBUTE_VALUE )
    self.assertTrue( date.getMinute() == 0 )
    i = date.setMinute(12121)
    self.assertTrue( i == libsbml.LIBSBML_INVALID_ATTRIBUTE_VALUE )
    self.assertTrue( date.getMinute() == 0 )
    i = date.setMinute(32)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( date.getMinute() == 32 )
    self.assertTrue((                             "2005-12-30T12:32:45+02:00" == date.getDateAsString() ))
    _dummyList = [ date ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Date_setMinutesOffset(self):
    date = libsbml.Date(2005,12,30,12,15,45,1,2,0)
    self.assertTrue( date != None )
    i = date.setMinutesOffset(434)
    self.assertTrue( i == libsbml.LIBSBML_INVALID_ATTRIBUTE_VALUE )
    self.assertTrue( date.getMinutesOffset() == 0 )
    i = date.setMinutesOffset(60)
    self.assertTrue( i == libsbml.LIBSBML_INVALID_ATTRIBUTE_VALUE )
    self.assertTrue( date.getMinutesOffset() == 0 )
    i = date.setMinutesOffset(45)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( date.getMinutesOffset() == 45 )
    self.assertTrue((                             "2005-12-30T12:15:45+02:45" == date.getDateAsString() ))
    _dummyList = [ date ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Date_setMonth(self):
    date = libsbml.Date(2005,12,30,12,15,45,1,2,0)
    self.assertTrue( date != None )
    i = date.setMonth(434)
    self.assertTrue( i == libsbml.LIBSBML_INVALID_ATTRIBUTE_VALUE )
    self.assertTrue( date.getMonth() == 1 )
    i = date.setMonth(12121)
    self.assertTrue( i == libsbml.LIBSBML_INVALID_ATTRIBUTE_VALUE )
    self.assertTrue( date.getMonth() == 1 )
    i = date.setMonth(11)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( date.getMonth() == 11 )
    self.assertTrue((                             "2005-11-30T12:15:45+02:00" == date.getDateAsString() ))
    _dummyList = [ date ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Date_setSecond(self):
    date = libsbml.Date(2005,12,30,12,15,45,1,2,0)
    self.assertTrue( date != None )
    i = date.setSecond(434)
    self.assertTrue( i == libsbml.LIBSBML_INVALID_ATTRIBUTE_VALUE )
    self.assertTrue( date.getSecond() == 0 )
    i = date.setSecond(12121)
    self.assertTrue( i == libsbml.LIBSBML_INVALID_ATTRIBUTE_VALUE )
    self.assertTrue( date.getSecond() == 0 )
    i = date.setSecond(32)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( date.getSecond() == 32 )
    self.assertTrue((                             "2005-12-30T12:15:32+02:00" == date.getDateAsString() ))
    _dummyList = [ date ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_Date_setYear(self):
    date = libsbml.Date(2005,12,30,12,15,45,1,2,0)
    self.assertTrue( date != None )
    i = date.setYear(434)
    self.assertTrue( i == libsbml.LIBSBML_INVALID_ATTRIBUTE_VALUE )
    self.assertTrue( date.getYear() == 2000 )
    i = date.setYear(12121)
    self.assertTrue( i == libsbml.LIBSBML_INVALID_ATTRIBUTE_VALUE )
    self.assertTrue( date.getYear() == 2000 )
    i = date.setYear(2008)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( date.getYear() == 2008 )
    self.assertTrue((                             "2008-12-30T12:15:45+02:00" == date.getDateAsString() ))
    _dummyList = [ date ]; _dummyList[:] = []; del _dummyList
    pass  

def suite():
  suite = unittest.TestSuite()
  suite.addTest(unittest.makeSuite(TestDate_newSetters))

  return suite

if __name__ == "__main__":
  if unittest.TextTestRunner(verbosity=1).run(suite()).wasSuccessful() :
    sys.exit(0)
  else:
    sys.exit(1)



#!/usr/bin/env python
##
## @file    setIdFromNames.py
## @brief   Utility program, renaming all SIds that also has
##          names specified. The new id will be derived from
##          the name, with all invalid characters removed. 
##
## @author  Frank T. Bergmann
## 
## 
## <!--------------------------------------------------------------------------
## This sample program is distributed under a different license than the rest
## of libSBML.  This program uses the open-source MIT license, as follows:
##
## Copyright (c) 2013-2018 by the California Institute of Technology
## (California, USA), the European Bioinformatics Institute (EMBL-EBI, UK)
## and the University of Heidelberg (Germany), with support from the National
## Institutes of Health (USA) under grant R01GM070923.  All rights reserved.
##
## Permission is hereby granted, free of charge, to any person obtaining a
## copy of this software and associated documentation files (the "Software"),
## to deal in the Software without restriction, including without limitation
## the rights to use, copy, modify, merge, publish, distribute, sublicense,
## and/or sell copies of the Software, and to permit persons to whom the
## Software is furnished to do so, subject to the following conditions:
##
## The above copyright notice and this permission notice shall be included in
## all copies or substantial portions of the Software.
##
## THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
## IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
## FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
## THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
## LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
## FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
## DEALINGS IN THE SOFTWARE.
##
## Neither the name of the California Institute of Technology (Caltech), nor
## of the European Bioinformatics Institute (EMBL-EBI), nor of the University
## of Heidelberg, nor the names of any contributors, may be used to endorse
## or promote products derived from this software without specific prior
## written permission.
## ------------------------------------------------------------------------ -->
## 
## 

import sys
import os.path
import time 
import libsbml

# This class implements an identifier transformer, that means it can be used
# to rename all sbase elements. 
class SetIdFromNames(libsbml.IdentifierTransformer):
  def __init__(self, ids):
    # call the constructor of the base class
    libsbml.IdentifierTransformer.__init__(self)
    # remember existing ids ...
    self.existingIds = ids

  # The function actually doing the transforming. This function is called 
  # once for each SBase element in the model. 
  def transform(self, element):
    # return in case we don't have a valid element
    if element is None or element.getTypeCode() == libsbml.SBML_LOCAL_PARAMETER:
        return libsbml.LIBSBML_OPERATION_SUCCESS

    # or if there is nothing to do
    if element.isSetName() == False or element.getId() == element.getName():
        return libsbml.LIBSBML_OPERATION_SUCCESS

    # find the new id
    newId = self.getValidIdForName(element.getName())

    # set it
    element.setId(newId)

    # remember it
    self.existingIds.append(newId)

    return libsbml.LIBSBML_OPERATION_SUCCESS

  def nameToSbmlId(self, name):
    IdStream = []
    count = 0
    end = len(name)
    
    if '0' <= name[count] and name[count] <= '9':
      IdStream.append('_')
    for  count in range (0, end):     
      if (('0' <= name[count] and name[count] <= '9') or
          ('a' <= name[count] and name[count] <= 'z') or
          ('A' <= name[count] and name[count] <= 'Z')):
          IdStream.append(name[count])
      else:
          IdStream.append('_')
    Id = ''.join(IdStream)
    if Id[len(Id) - 1] != '_':
        return Id

    return Id[:-1]
  # 
  # Generates the id out of the name, and ensures it is unique. 
  # It does so by appending numbers to the original name. 
  # 
  def getValidIdForName(self, name):
    baseString = self.nameToSbmlId(name)
    id = baseString
    count = 1
    while self.existingIds.count(id) != 0:
      id = "{0}_{1}".format(baseString, count)
      count += 1
    return id


# 
# Returns a list of all ids from the given list of elements
# 
def getAllIds(allElements):
    result = []
    if allElements is None or allElements.getSize() == 0:
        return result

    for i in range (0, allElements.getSize()):
        current = allElements.get(i)
        if current.isSetId() and current.getTypeCode() != libsbml.SBML_LOCAL_PARAMETER:
            result.append(current.getId())
    return result


def main (args):
  """Usage: setIdFromNames filename output
  """
  if len(args) != 3:
    print(main.__doc__)
    sys.exit(1)
  
  filename = args[1]
  output = args[2]

  # read the document
  start = time.time() * 1000
  document = libsbml.readSBMLFromFile(filename)
  stop = time.time() * 1000

  print ("")
  print ("            filename: {0}".format( filename))
  print ("      read time (ms): {0}".format( stop - start))

  # stop in case of serious errors
  errors = document.getNumErrors(libsbml.LIBSBML_SEV_ERROR)
  if errors > 0:
      print ("            error(s): {0}".format(errors))
      document.printErrors()
      sys.exit (errors)

  # get a list of all elements, as we will need to know all identifiers
  # so that we don't create duplicates. 
  allElements = document.getListOfAllElements()

  # get a list of all ids
  allIds = getAllIds(allElements)

  # create the transformer with the ids
  trans = SetIdFromNames(allIds)

  # rename the identifiers (using the elements we already gathered before)
  start = time.time() * 1000
  document.getModel().renameIDs(allElements, trans)
  stop = time.time() * 1000
  print ("    rename time (ms): {0}".format(stop - start))

  # write to file
  start = time.time() * 1000
  libsbml.writeSBMLToFile(document, output)
  stop = time.time() * 1000
  print ("     write time (ms): {0}".format(stop - start))
  print ("")

  # if we got here all went well ... 
  
if __name__ == '__main__':
  main(sys.argv)  



from libsbml import *

arraysNs = ArraysPkgNamespaces();
doc = SBMLDocument(arraysNs);
doc.setPackageRequired("arrays", True);
model = doc.createModel();

# create parameters
param = model.createParameter();
param.setId("n");
param.setValue(10);
param.setConstant(True);

param = model.createParameter();
param.setId("m");
param.setValue(10);
param.setConstant(True);

param = model.createParameter();
param.setId("x");
param.setValue(5.7);
param.setConstant(True);

paramPlugin = param.getPlugin("arrays");
dim = paramPlugin.createDimension();
dim.setId("i");
dim.setSize("n");

param = model.createParameter();
param.setId("y");
param.setConstant(False);

paramPlugin = param.getPlugin("arrays");
dim = paramPlugin.createDimension();
dim.setId("i");
dim.setSize("n");

param = model.createParameter();
param.setId("z");
param.setConstant(False);

paramPlugin = param.getPlugin("arrays");
dim = paramPlugin.createDimension();
dim.setId("i");
dim.setSize("n");

# create initial assignments

assignment = model.createInitialAssignment();
assignment.setSymbol("y");
ast = ASTNode(AST_REAL);
ast.setValue(3.2);
assignment.setMath(ast);

assignment = model.createInitialAssignment();
assignment.setSymbol("z");
ast = ASTNode(AST_REAL);
ast.setValue(5.7);
assignment.setMath(ast);

assignmentPlugin = assignment.getPlugin("arrays");
dim = assignmentPlugin.createDimension();
dim.setId("i");
dim.setSize("m");

index = assignmentPlugin.createIndex();
newAst = ASTNode(AST_LINEAR_ALGEBRA_SELECTOR);
ci1 = ASTNode(AST_NAME);
ci1.setName("z");
newAst.addChild(ci1);
ci2 = ASTNode(AST_NAME);
ci2.setName("i");
newAst.addChild(ci2);
index.setMath(newAst);

assignment = model.createInitialAssignment();
assignment.setSymbol("z");
ast = ASTNode(AST_REAL);
ast.setValue(3.2);
assignment.setMath(ast);

assignmentPlugin = assignment.getPlugin("arrays");
dim = assignmentPlugin.createDimension();
dim.setId("i");
dim.setSize("m");

index = assignmentPlugin.createIndex();
newAst = ASTNode(AST_LINEAR_ALGEBRA_SELECTOR);
ci = ASTNode(AST_NAME);
ci.setName("z");
newAst.addChild(ci);
plus = ASTNode(AST_PLUS);

ci1 = ASTNode(AST_NAME);
ci1.setName("i");
plus.addChild(ci1);
ci2 = ASTNode(AST_NAME);
ci2.setName("m");
plus.addChild(ci2);
newAst.addChild(plus);
index.setMath(newAst);

writeSBMLToFile(doc, "arrays2.xml");



#!/usr/bin/env python
## 
## @file    stringInput.py
## @brief   illustrates how libSBML deals with string and unicode input
## @author  Brett Olivier
## 
## <!--------------------------------------------------------------------------
## This sample program is distributed under a different license than the rest
## of libSBML.  This program uses the open-source MIT license, as follows:
##
## Copyright (c) 2013-2018 by the California Institute of Technology
## (California, USA), the European Bioinformatics Institute (EMBL-EBI, UK)
## and the University of Heidelberg (Germany), with support from the National
## Institutes of Health (USA) under grant R01GM070923.  All rights reserved.
##
## Permission is hereby granted, free of charge, to any person obtaining a
## copy of this software and associated documentation files (the "Software"),
## to deal in the Software without restriction, including without limitation
## the rights to use, copy, modify, merge, publish, distribute, sublicense,
## and/or sell copies of the Software, and to permit persons to whom the
## Software is furnished to do so, subject to the following conditions:
##
## The above copyright notice and this permission notice shall be included in
## all copies or substantial portions of the Software.
##
## THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
## IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
## FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
## THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
## LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
## FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
## DEALINGS IN THE SOFTWARE.
##
## Neither the name of the California Institute of Technology (Caltech), nor
## of the European Bioinformatics Institute (EMBL-EBI), nor of the University
## of Heidelberg, nor the names of any contributors, may be used to endorse
## or promote products derived from this software without specific prior
## written permission.
## ------------------------------------------------------------------------ -->
## 

import sys
import os.path
import libsbml

def main (args):
  """Usage: stringInput filename
  """

  if len(args) != 2:
    print(main.__doc__)
    sys.exit(2)

  filename = args[1]
  document = libsbml.readSBMLFromFile(filename)

  errors = document.getNumErrors()

  print("filename: " + filename + "\n")

  if errors > 0:
      document.printErrors()
      return errors

  # Model
  
  m = document.getModel()

  # testing ascii input, this should work for Python 2 and 3
  
  ascii_name = str('new_ascii_name')
  m.setName(ascii_name)
  
  print(type(m.getName()))
  
  # testing unicode input, this should also work for Python 3 and
  # Python 2 if libSBML has been compiled with Swig version > 3.0.8
  
  unicode_name = u'new_unicode_name'
  m.setName(unicode_name)
  
  print(type(m.getName()))
  
  return errors


if __name__ == '__main__':
  main(sys.argv)  



#
# @file    TestL3KineticLaw.py
# @brief   L3 KineticLaw unit tests
#
# @author  Akiya Jouraku (Python conversion)
# @author  Sarah Keating 
# 
# ====== WARNING ===== WARNING ===== WARNING ===== WARNING ===== WARNING ======
#
# DO NOT EDIT THIS FILE.
#
# This file was generated automatically by converting the file located at
# src/sbml/test/TestL3KineticLaw.c
# using the conversion program dev/utilities/translateTests/translateTests.pl.
# Any changes made here will be lost the next time the file is regenerated.
#
# -----------------------------------------------------------------------------
# This file is part of libSBML.  Please visit http://sbml.org for more
# information about SBML, and the latest version of libSBML.
#
# Copyright 2005-2010 California Institute of Technology.
# Copyright 2002-2005 California Institute of Technology and
#                     Japan Science and Technology Corporation.
# 
# This library is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation.  A copy of the license agreement is provided
# in the file named "LICENSE.txt" included with this software distribution
# and also available online as http://sbml.org/software/libsbml/license.html
# -----------------------------------------------------------------------------

import sys
import unittest
import libsbml


class TestL3KineticLaw(unittest.TestCase):

  global KL
  KL = None

  def setUp(self):
    self.KL = libsbml.KineticLaw(3,1)
    if (self.KL == None):
      pass    
    pass  

  def tearDown(self):
    _dummyList = [ self.KL ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_L3_KineticLaw_addParameter1(self):
    kl = libsbml.KineticLaw(3,1)
    p = libsbml.Parameter(3,1)
    i = self.KL.addParameter(p)
    self.assertTrue( i == libsbml.LIBSBML_INVALID_OBJECT )
    p.setId( "p")
    i = self.KL.addParameter(p)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( self.KL.getNumParameters() == 1 )
    self.assertTrue( self.KL.getNumLocalParameters() == 1 )
    self.assertTrue( kl.getNumParameters() == 0 )
    self.assertTrue( kl.getNumLocalParameters() == 0 )
    i = kl.addParameter(p)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( self.KL.getNumParameters() == 1 )
    self.assertTrue( self.KL.getNumLocalParameters() == 1 )
    self.assertTrue( kl.getNumParameters() == 1 )
    self.assertTrue( kl.getNumLocalParameters() == 1 )
    _dummyList = [ p ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ kl ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_L3_KineticLaw_addParameter2(self):
    kl = libsbml.KineticLaw(3,1)
    lp = libsbml.LocalParameter(3,1)
    lp1 = libsbml.LocalParameter(3,1)
    i = kl.addLocalParameter(lp)
    self.assertTrue( i == libsbml.LIBSBML_INVALID_OBJECT )
    lp.setId( "p")
    lp1.setId("p1");
    i = kl.addLocalParameter(lp)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( kl.getNumParameters() == 1 )
    self.assertTrue( kl.getNumLocalParameters() == 1 )
    i = kl.addParameter(lp1)
    self.assertTrue( i == libsbml.LIBSBML_OPERATION_SUCCESS )
    self.assertTrue( kl.getNumParameters() == 2 )
    self.assertTrue( kl.getNumLocalParameters() == 2 )
    _dummyList = [ lp ]; _dummyList[:] = []; del _dummyList
    _dummyList = [ kl ]; _dummyList[:] = []; del _dummyList
    pass  

  def test_L3_KineticLaw_create(self):
    self.assertTrue( self.KL.getTypeCode() == libsbml.SBML_KINETIC_LAW )
    self.assertTrue( self.KL.getMetaId() == "" )
    self.assertTrue( self.KL.getNotes() == None )
    self.assertTrue( self.KL.getAnnotation() == None )
    self.assertTrue( self.KL.getNumParameters() == 0 )
    self.assertTrue( self.KL.getNumLocalParameters() == 0 )
    pass  

  def test_L3_KineticLaw_free_NULL(self):
    _dummyList = [ None ]; _dummyList[:] = []; del _dummyList
    pass  

def suite():
  suite = unittest.TestSuite()
  suite.addTest(unittest.makeSuite(TestL3KineticLaw))

  return suite

if __name__ == "__main__":
  if unittest.TextTestRunner(verbosity=1).run(suite()).wasSuccessful() :
    sys.exit(0)
  else:
    sys.exit(1)
